cd 'E:\Mis Documentos D\Modtran LUTGen\Software\LUTGen\Help\Tutorials\tutorial1'
addpath(genpath('E:\Mis Documentos D\Modtran LUTGen\Software\LUTGen\MatlabCode'))

%%
% File name (without extension)
filename = 'tutorial1';

% Read LUT header file and LUT output file
hdr = readLUThdr([filename,'.hdr']);
Y   = h5read([filename,'.h5'],'/LUTdata');

%% 
%Separate LUT output in atmospheric transfer functions (see hdr.outnames
% for further information about the order of these functions in Y):
L0   = Y(1:numel(hdr.wvl),:);
Tgas = Y(numel(hdr.wvl)+1:2*numel(hdr.wvl),:);
Etot = Y(2*numel(hdr.wvl)+1:3*numel(hdr.wvl),:);
Ttot = Y(3*numel(hdr.wvl)+1:4*numel(hdr.wvl),:);
S    = Y(4*numel(hdr.wvl)+1:5*numel(hdr.wvl),:);

%% Construct TOA radiance
rho = importdata('refldb.txt'); rho = spline(rho(:,1),rho(:,2),hdr.wvl);
filter1 = hdr.LUTheader(1,:)==2;
LTOA = L0 + (1/pi)*(bsxfun(@times,Tgas.*Etot.*Ttot,rho))./(1-bsxfun(@times,S,rho));

% Plot reflectance:
figure(1)
plot(hdr.wvl,rho,'color',[0 0.5 0],'linewidth',2)
xlim([min(hdr.wvl),max(hdr.wvl)]), ylim([0,max(rho)])
xlabel('Wavelength (nm)'), ylabel('Reflectance (-)'), grid on
set(gcf,'position',[200 300 550 300])

% Plot TOA radiance:
figure(2)
plot(hdr.wvl,LTOA(:,filter1 & hdr.LUTheader(4,:)==30),'linewidth',1.5), hold on
plot(hdr.wvl,LTOA(:,filter1 & hdr.LUTheader(4,:)==60),'linewidth',1.5,'linestyle',':')
xlim([min(hdr.wvl),max(hdr.wvl)]), ylim([min(min(LTOA(:,filter1))),max(max(LTOA(:,filter1)))])
xlabel('Wavelength (nm)'), ylabel('L_{TOA} (mWm^{-2}sr^{-1}nm^{-1})'), grid on
set(gcf,'position',[200 200 550 300])

%% Atmospheric correction
filter2 = hdr.LUTheader(1,:)==3;
A = pi*(LTOA(:,filter1) - L0(:,filter2));
B = Tgas.*Etot.*Ttot; B = B(:,filter2);
rho_corr = A./(B+A.*S(:,filter2));

figure(3)
plot(hdr.wvl,rho_corr,'linewidth',1.5), hold on
plot(hdr.wvl,rho,'--r','linewidth',2)
xlim([min(hdr.wvl),max(hdr.wvl)]), ylim([0 0.7])
xlabel('Wavelength (nm)'), ylabel('Reflectance (-)'), grid on
set(gcf,'position',[500 300 550 300])


