cd 'E:\Mis Documentos D\Modtran LUTGen\Software\LUTGen\Help\Tutorials\tutorial2'
addpath(genpath('E:\Mis Documentos D\Modtran LUTGen\Software\LUTGen\MatlabCode'))

%%
% File names (without extension)
fileref = 'reference';
fileret = 'retrieval';

%% Approximation in aerosol optical properties
% Read OPAC output data .h5 file:
OPACscript


%% Error analysis in atmospheric correction
% Read LUT header file and LUT output file
hdr1 = readLUThdr([fileref,'.hdr']);         hdr2 = readLUThdr([fileret,'.hdr']);
Y1   = h5read([fileref,'.h5'],'/LUTdata');   Y2   = h5read([fileret,'.h5'],'/LUTdata');

% Separate LUT output in atmospheric transfer functions (see hdr.outnames
% for further information about the order of these functions in Y1):
L0   = Y1(1:numel(hdr1.wvl),:);
Edir = Y1(numel(hdr1.wvl)+1:2*numel(hdr1.wvl),:);
Edif = Y1(2*numel(hdr1.wvl)+1:3*numel(hdr1.wvl),:);
S    = Y1(3*numel(hdr1.wvl)+1:4*numel(hdr1.wvl),:);
Tdir = Y1(4*numel(hdr1.wvl)+1:5*numel(hdr1.wvl),:);
Tdif = Y1(5*numel(hdr1.wvl)+1:6*numel(hdr1.wvl),:);

% Construct TOA radiance (reference)
rho = importdata('../tutorial1/refldb.txt'); rho = spline(rho(:,1),rho(:,2),hdr1.wvl);
LTOA_ref = L0 + (1/pi)*(bsxfun(@times,(Edir*cosd(hdr1.SZA)+Edif).*(Tdir+Tdif),rho))./(1-bsxfun(@times,S,rho));

% Plot reflectance:
figure(1)
plot(hdr1.wvl,rho,'color',[0 0.5 0],'linewidth',2)
xlim([min(hdr1.wvl),max(hdr1.wvl)]), ylim([0,max(rho)])
xlabel('Wavelength (nm)'), ylabel('Reflectance (-)'), grid on
set(gcf,'position',[200 600 550 300])


% Separate LUT output in atmospheric transfer functions (see hdr.outnames
% for further information about the order of these functions in Y1):
L0   = Y2(1:numel(hdr2.wvl),:);
Edir = Y2(numel(hdr2.wvl)+1:2*numel(hdr2.wvl),:);
Edif = Y2(2*numel(hdr2.wvl)+1:3*numel(hdr2.wvl),:); Etot = Edir*cosd(hdr2.SZA)+Edif;
S    = Y2(3*numel(hdr2.wvl)+1:4*numel(hdr2.wvl),:);
Tdir = Y2(4*numel(hdr2.wvl)+1:5*numel(hdr2.wvl),:); 
Tdif = Y2(5*numel(hdr2.wvl)+1:6*numel(hdr2.wvl),:); Ttot = Tdir+Tdif;

% Construct TOA radiance (reference)
LTOA_ret = L0 + (1/pi)*(bsxfun(@times,(Edir*cosd(hdr1.SZA)+Edif).*(Tdir+Tdif),rho))./(1-bsxfun(@times,S,rho));

% Plot all reference and retrieval spectra
figure(2)
plot(hdr1.wvl,LTOA_ret(:,1),'r'), hold on, plot(hdr1.wvl,LTOA_ref(:,1),'--b')
legend('Retrieval','Reference')
plot(hdr1.wvl,LTOA_ret,'r'), hold on, plot(hdr1.wvl,LTOA_ref,'--b')
xlim([min(hdr2.wvl),max(hdr2.wvl)]), ylim([min(LTOA_ret(:)),max(LTOA_ret(:))])
xlabel('Wavelength (nm)'), ylabel('L_{TOA} (mWm^{-2}sr^{-1}nm^{-1})'), grid on
set(gcf,'position',[200 300 550 300])

% Find combinations in retrieval LUT matching radiances in reference LUT:
filter = (hdr1.wvl>=686 & hdr1.wvl<=708) | (hdr1.wvl>=758 & hdr1.wvl<=772) | (hdr1.wvl>=713 & hdr1.wvl<=753) | (hdr1.wvl>=780 & hdr1.wvl<=850) | (hdr1.wvl>=891 & hdr1.wvl<=986);
error = zeros([size(LTOA_ref,2),size(LTOA_ret,2)]);
for i=1:size(LTOA_ref,2)
    for j=1:size(LTOA_ret,2)
        error(i,j) = sum((LTOA_ref(~filter,i)-LTOA_ret(~filter,j)).^2);
    end
end

[~,jmax] = min(error,[],2);

% Best atmospheric correction
A = pi*(LTOA_ref - L0(:,jmax));
B = Etot.*Ttot; B = B(:,jmax);
rho_corr = A./(B+A.*S(:,jmax));

figure(3), hold on
C = {[0 1 0],[0 0.65 0],[0 0 0],[1 0 0],[1 0.5 0],'c',[0 0 1],[0 0 0.65]};
for i=1:size(LTOA_ref,2)
    plot(hdr1.wvl,100*(rho_corr(:,i)-rho)./rho,'linewidth',1.5,'color',C{i})
end
xlim([min(hdr1.wvl),max(hdr1.wvl)]), ylim([-5 3])
xlabel('Wavelength (nm)'), ylabel('Relative error (%)'), grid on
set(gcf,'position',[500 300 550 300])
