cd 'E:\Mis Documentos D\Modtran LUTGen\Software\LUTGen\Help\Tutorials\tutorial3'
addpath(genpath('E:\Mis Documentos D\Modtran LUTGen\Software\LUTGen\MatlabCode'))

%%
% File names (without extension)
file1 = 'modtranLUT';
file2 = '6svLUT';


%% Intercomparison of MODTRAN and 6SV LUTs
% Read LUT header file and LUT output file
hdr1 = readLUThdr([file1,'.hdr']);         hdr2 = readLUThdr([file2,'.hdr']);
Y1   = h5read([file1,'.h5'],'/LUTdata');   Y2   = h5read([file2,'.h5'],'/LUTdata');

% Separate MODTRAN LUT output in atmospheric transfer functions (see hdr.outnames
% for further information about the order of these functions in Y1):
L01  = Y1(1:numel(hdr1.wvl),:);
Edir = Y1(numel(hdr1.wvl)+1:2*numel(hdr1.wvl),:);
Edif = Y1(2*numel(hdr1.wvl)+1:3*numel(hdr1.wvl),:);
S1   = Y1(3*numel(hdr1.wvl)+1:4*numel(hdr1.wvl),:);
Tdir = Y1(4*numel(hdr1.wvl)+1:5*numel(hdr1.wvl),:);
Tdif = Y1(5*numel(hdr1.wvl)+1:6*numel(hdr1.wvl),:);

% Same for 6SV atmospheric transfer functions:
L02  = Y2(1:numel(hdr2.wvl),:);
Tgas = Y2(numel(hdr2.wvl)+1:2*numel(hdr2.wvl),:);
Etot = Y2(2*numel(hdr2.wvl)+1:3*numel(hdr2.wvl),:);
Ttot = Y2(3*numel(hdr2.wvl)+1:4*numel(hdr2.wvl),:);
S2   = Y2(4*numel(hdr2.wvl)+1:5*numel(hdr2.wvl),:);

% Construct TOA radiance
rho = [0.05 0.4];
for i=1:numel(rho)
    LTOA_aux(:,:,i) = L01 + (1/pi)*((bsxfun(@times,Edir,cosd(hdr1.SZA))+Edif).*(Tdir+Tdif)*rho(i))./(1-S1*rho(i));
    LTOA_2(:,:,i)   = L02 + (1/pi)*(Tgas.*Etot.*Ttot*rho(i))./(1-S2*rho(i));
end

% Average TOA radiance spectra in MODTRAN to match resolution in 6SV:
LTOA_1(1,:,:) = mean(LTOA_aux(1:9,:,:)); LTOA_1(2,:,:) = mean(LTOA_aux(10:end,:,:));

% Calculate error metric:
VZA = unique(hdr1.LUTheader(4,:)); % Same in both MODTRAN and 6SV LUTs
AOT = unique(hdr1.LUTheader(2,:)); % Same in both MODTRAN and 6SV LUTs
IHAZE = unique(hdr1.LUTheader(1,:)); % Aerosol type for MODTRAN LUT
MAERO = unique(hdr2.LUTheader(1,:)); % Aerosol type for 6SV LUT
delta1 = zeros(numel(VZA),numel(AOT),numel(rho),numel(IHAZE)); % Channel at 440 nm
delta2 = zeros(numel(VZA),numel(AOT),numel(rho),numel(IHAZE)); % Channel at 670 nm

for i=1:numel(VZA)
    for j=1:numel(AOT)
        for k=1:numel(rho)
            ind = hdr1.LUTheader(4,:)==VZA(i) & hdr1.LUTheader(2,:)==AOT(j) & hdr1.LUTheader(3,:)<75;
            % Calculation for Maritime aerosol (IHAZE=4 and MAERO=2):
            ind1 = ind & hdr1.LUTheader(1,:)==IHAZE(1);
            ind2 = ind & hdr2.LUTheader(1,:)==MAERO(1);
            delta1(i,j,k,1) = (100/sum(ind1))*sum(abs(LTOA_1(1,ind1,k)-LTOA_2(1,ind2,k))./LTOA_2(1,ind2,k));
            delta2(i,j,k,1) = (100/sum(ind1))*sum(abs(LTOA_1(2,ind1,k)-LTOA_2(2,ind2,k))./LTOA_2(2,ind2,k));
            % Calculation for Urban aerosol (IHAZE=5 and MAERO=3):
            ind1 = ind & hdr1.LUTheader(1,:)==IHAZE(2);
            ind2 = ind & hdr2.LUTheader(1,:)==MAERO(2);
            delta1(i,j,k,2) = (100/sum(ind1))*sum(abs(LTOA_1(1,ind1,k)-LTOA_2(1,ind2,k))./LTOA_2(1,ind2,k));
            delta2(i,j,k,2) = (100/sum(ind1))*sum(abs(LTOA_1(2,ind1,k)-LTOA_2(2,ind2,k))./LTOA_2(2,ind2,k));
        end
    end
end

%%
% Plot for rho=0.05:
figure(1)
h1=subplot(1,2,1);
    plot(VZA(1:end-1),delta1(1:end-1,1,1,1),'--ok','linewidth',1), hold on, grid on
    plot(VZA(1:end-1),delta1(1:end-1,2,1,1),'--.k','linewidth',1,'markersize',15)
    plot(VZA(1:end-1),delta2(1:end-1,1,1,1),'--^k','linewidth',1)
    plot(VZA(1:end-1),delta2(1:end-1,2,1,1),'--vk','linewidth',1,'markersize',5)
    xlim([0 80]), ylim([0,30])
    title('Maritime aerosol')
    xlabel('VZA (deg)'), ylabel('Average difference (%)')
h2=subplot(1,2,2);
    plot(VZA(1:end-1),delta1(1:end-1,1,1,2),'--ok','linewidth',1), hold on, grid on
    plot(VZA(1:end-1),delta1(1:end-1,2,1,2),'--.k','linewidth',1,'markersize',15)
    plot(VZA(1:end-1),delta2(1:end-1,1,1,2),'--^k','linewidth',1)
    plot(VZA(1:end-1),delta2(1:end-1,2,1,2),'--vk','linewidth',1,'markersize',5)
    xlim([0 80]), ylim([0,30])
    title('Urban aerosol')
    xlabel('VZA (deg)'), ylabel('Average difference (%)')
    hleg=legend('0.2; 440','0.8; 440','0.2; 670','0.8; 670');
set(gcf,'position',[200 300 1100 300])
set(h1,'position',[0.05 0.15 0.35 0.75]), set(h2,'position',[0.50 0.15 0.35 0.75])
set(hleg,'position',[0.88 0.65 0.1 0.2])

% Plot for rho=0.40:
figure(2)
h1=subplot(1,2,1);
    plot(VZA(1:end-1),delta1(1:end-1,1,2,1),'--ok','linewidth',1), hold on, grid on
    plot(VZA(1:end-1),delta1(1:end-1,2,2,1),'--.k','linewidth',1,'markersize',15)
    plot(VZA(1:end-1),delta2(1:end-1,1,2,1),'--^k','linewidth',1)
    plot(VZA(1:end-1),delta2(1:end-1,2,2,1),'--vk','linewidth',1,'markersize',5)
    xlim([0 80]), ylim([0,30])
    title('Maritime aerosol')
    xlabel('VZA (deg)'), ylabel('Average difference (%)')
h2=subplot(1,2,2);
    plot(VZA(1:end-1),delta1(1:end-1,1,2,2),'--ok','linewidth',1), hold on, grid on
    plot(VZA(1:end-1),delta1(1:end-1,2,2,2),'--.k','linewidth',1,'markersize',15)
    plot(VZA(1:end-1),delta2(1:end-1,1,2,2),'--^k','linewidth',1)
    plot(VZA(1:end-1),delta2(1:end-1,2,2,2),'--vk','linewidth',1,'markersize',5)
    xlim([0 80]), ylim([0,30])
    title('Urban aerosol')
    xlabel('VZA (deg)'), ylabel('Average difference (%)')
    hleg=legend('0.2; 440','0.8; 440','0.2; 670','0.8; 670');
set(gcf,'position',[200 300 1100 300])
set(h1,'position',[0.05 0.15 0.35 0.75]), set(h2,'position',[0.50 0.15 0.35 0.75])
set(hleg,'position',[0.88 0.65 0.1 0.2])

