cd 'E:\Mis Documentos D\Modtran LUTGen\Software\LUTGen\Help\Tutorials\tutorial4'
addpath(genpath('E:\Mis Documentos D\Modtran LUTGen\Software\LUTGen\MatlabCode'))

%%
% File names (without extension)
files = {'reference',...
         'disort2KSF','disort4KSF','disort8KSF','disort16KSF',...
         'isaac0KS','isaac-1KS',...
         'disort2KST','disort4KST','disort8KST','disort16KST',...
         'disort2KMF','disort4KMF','disort8KMF','disort16KMF',...
         'isaac0KM','isaac-1KM',...
         'disort2KMT','disort4KMT','disort8KMT','disort16KMT',...
         'disort2MF','disort4MF','disort8MF','disort16MF',...
         'isaac0M','isaac-1M',...
         'disort2MT','disort4MT','disort8MT','disort16MT'};

files = {'reference','disort8KSF','disort8KMF','isaac-1KS'};     
%% Create OLCI TOA radiance LUTs
for i=1:numel(files)
    % Read LUT header file and LUT output file
    hdr = readLUThdr(['flex/',files{i},'.h5']);
    Y   = h5read(['flex/',files{i},'.h5'],'/LUTdata'); 

    % Separate MODTRAN LUT output in atmospheric transfer functions (see hdr.outnames
    % for further information about the order of these functions in Y1):
    L0   = Y(1:numel(hdr.wvl),:);
    Edir = Y(numel(hdr.wvl)+1:2*numel(hdr.wvl),:);
    Edif = Y(2*numel(hdr.wvl)+1:3*numel(hdr.wvl),:);
    S    = Y(3*numel(hdr.wvl)+1:4*numel(hdr.wvl),:);
    Tdir = Y(4*numel(hdr.wvl)+1:5*numel(hdr.wvl),:);
    Tdif = Y(5*numel(hdr.wvl)+1:6*numel(hdr.wvl),:);
    
    Etot = Edir.*cosd(hdr.SZA) + Edif;
    Ttot = Tdir + Tdif;

	% Read reflectance data:
    aux = importdata('soil.txt');
    rho_s = spline(aux(:,1)*1000,aux(:,2)/100,hdr.wvl);
    ind = hdr.wvl<aux(1,1)*1000 | hdr.wvl>aux(end,1)*1000;
    rho_s(ind) = interp1(aux(:,1)*1000,aux(:,2)/100,hdr.wvl(ind),'linear','extrap');
    rho_v = importdata('../tutorial1/refldb.txt'); rho_v = spline(rho_v(:,1),rho_v(:,2),hdr.wvl);
    if i==1
        % Plot reflectance:
        figure(1)
        plot(hdr.wvl,rho_s,'-','color',[0.8 0.4 0],'linewidth',2), hold on
        plot(hdr.wvl,rho_v,'-','color',[0 0.5 0],'linewidth',2)
        xlim([min(hdr.wvl),max(hdr.wvl)]), ylim([0,max(rho_v)])
        xlabel('Wavelength (nm)'), ylabel('Reflectance (-)'), grid on
        legend('soil','vegetation')
        set(gcf,'position',[200 300 550 300])
    end
    
    % Construct high spectral resolution TOA radiance:
    aux1 = L0 + (1/pi)*(Etot.*Ttot.*rho_s)./(1-S.*rho_s);
    aux2 = L0 + (1/pi)*(Etot.*Ttot.*rho_v)./(1-S.*rho_v);
    LTOA = [aux1,aux2];
    
    % Spectral convolution:
    C = [400 401.25 442.5 490 510 560 620 665 673.75 681.25 708.75 753.75...
         761.25 764.375 767.5 778.75 865 885 900 940 1020]; % OLCI spectral channels (nm)
    B = [15 10 10 10 10 10 10 10 7.5 7.5 10 7.5 2.5 3.75 2.5...
         15 20 10 10 20 40]; % OLCI spectral resolution (nm)
    C = 500:0.1:780; B = 0.3;
    if i==1
        OLCIref = convolve_ISRF(hdr.wvl,LTOA,C,B,'trap');
    else
        OLCI(:,:,i-1) = convolve_ISRF(hdr.wvl,LTOA,C,B,'trap');
    end
end

%% Error metric and Plots:
% Mean spectral error
delta = 100*squeeze(mean(bsxfun(@rdivide,abs(bsxfun(@minus,OLCIref,OLCI)),OLCIref),2));

aux = flipud(jet);
colOrd = [aux([1 8 15 20],:);aux([64 48],:)];
set(0,'DefaultAxesColorOrder',colOrd)
set(0,'DefaultAxesLineStyleOrder','-o|--x')

figure(2) % Mean spectral error plots
h1=subplot(1,3,1); % For Correlated-k Slow speed (KS)
    semilogy(C,delta(:,1:10),'linewidth',1), grid on
    xlim([350 1050]), ylim([0.005,60])
    set(gca,'ytick',[0.01 0.1 1 10])
    title('Correlated-k (slow)')
    xlabel('Wavelength (nm)'), ylabel('Average difference (%)')
h2=subplot(1,3,2); % For Correlated-k Medium speed (KM)
    semilogy(C,delta(:,11:20),'linewidth',1), grid on
    xlim([350 1050]), ylim([0.005,60])
    set(gca,'ytick',[0.01 0.1 1 10])
    title('Correlated-k (medium)')
    xlabel('Wavelength (nm)'), ylabel('Average difference (%)')
h3=subplot(1,3,3); % For Band Model (M)
    semilogy(C,delta(:,21:30),'linewidth',1), grid on
    xlim([350 1050]), ylim([0.005,60])
    set(gca,'ytick',[0.01 0.1 1 10])
    title('Band model')
    xlabel('Wavelength (nm)'), ylabel('Average difference (%)')    
    hleg=legend('DIS (2)','DIS (4)','DIS (8)','DIS (16)','Isaac','Scaled Isaac');
set(gcf,'position',[200 300 1100 300])
set(h1,'position',[0.05 0.19 0.27 0.75])
set(h2,'position',[0.38 0.19 0.27 0.75])
set(h3,'position',[0.71 0.19 0.27 0.75])
set(hleg,'position',[0.5 -0.05 0.1 0.2],'orientation','horizontal')

% Computation time
data = importdata('olci/time.txt'); time = data.data; % Read CPU time data
time = time(time~=0); time=time(2:end);
figure(3) % CPU time vs mean error
h1 = subplot(1,2,1);
    ind = [5 6 1 2 3 4 7 8 9 10];
    semilogy(time(ind),'--ro'), hold on, grid on
    semilogy(time(ind+10),'--x','color',[0 0.5 0])
    semilogy(time(ind+20),'--bs')
    xlim([0 11]), ylim([0.05 5]), set(gca,'xtick',1:10)
    xlabel('Case number (-)'), ylabel('CPU time (min/simulation)')
    title('Computation time')
h2 = subplot(1,2,2);
    semilogy(mean(delta(:,ind)),'--ro'), hold on, grid on
    semilogy(mean(delta(:,ind+10)),'--x','color',[0 0.5 0])
    semilogy(mean(delta(:,ind+20)),'--bs')
    xlim([0 11]), ylim([0.01 30]), set(gca,'xtick',1:10)
    xlabel('Case number (-)'), ylabel('Mean difference (%)')
    title('Mean difference')

str = {'{\bf Test cases:}','#1  Isaac 2-stream','#2  Scaled Isaac',...
       '#3  DIS (2; MIT)','#4  DIS (4; MIT)','#5  DIS (8; MIT)',...
       '#6  DIS (16; MIT)','#7  DIS (2; DISALB)','#8  DIS (4; DISALB)',...
       '#9  DIS (8; DISALB)','#10 DIS (16; DISALB)'};
annotation('textbox',[0.84 0.15 0.14 0.75],'String',str);

set(gcf,'position',[200 300 1100 300])
set(h1,'position',[0.05 0.15 0.35 0.75]), set(h2,'position',[0.47 0.15 0.35 0.75])
hleg=legend('Correlated-k (slow)','Correlated-k (medium)','Band model');


