function generateRTMinputs(alg)
%GENERATERTMINPUTS Generate RTM inputs for Look-Up table grid points
%   GENERATERTMINPUTS(ALG) generates all the necessary input files for the 
%   execution of an RTM and generation of a Look-Up Table (LUT). 
%   GENERATERTMINPUTS uses the ALG class, which containing information 
%   about the LUT configuration, LUT input variables and its values
%
%   See also: LUTGEN_INPUTS, ALG

%   Copyright 2019 Image Processing Laboratory (IPL), Univ. of Valencia.
%   Contact: jorge.vicent@uv.es
%   $Revision: 1.05 $  $Date: 2019/01/24 $


cellfind = @(string)(@(cell_contents)(strcmp(string,cell_contents)));

% RTM input variable names and values to static variables:
alg = alg.findInputVariables();

% Read aerosol optical properties input by the user (if any):
alg = alg.readAerosols();

% Read atmospheric profiles input by the user (if any):
alg = alg.readAtmospheres();

h = waitbar(0,'','Name',['Configuring ',alg.GenConf.RTMname,' execution. Please wait...']);
color = [66,139,202]/255; set(findobj(h,'type','patch'),'facecolor',color);

% Write input files for the selected RTM and LUT grid points:
alg.writeInputs(h)


