function updateLUThdr(alg,wvl,I0,outvarnames,LUTheader)
%UPDATELUTHDR Update Look-Up table header file with output variable names
%and wavelengths
%   UPDATELUTHDR(FILENAME,WVL,OUTVARNAMES,LUTHEADER) updates the existing 
%   LUT header file FILENAME with a descriptive name of the output LUT 
%   variables in the cell structure OUTVARNAMES, the vector of wavelengths 
%   in WVL (in [nm]) and the vector of extraterrestial solar irradiance I0
%   (in [mW/m2/nm]). If I0, WLV and OUTVARNAMES are empty and the
%   matrix LUTHEADER is included, the LUT header file will update the input
%   variables.
%
%   See also: LUTGEN_PROCESS, READLUTHDR, WRITELUTHDR

%   Copyright 2019 Image Processing Laboratory (IPL), Univ. of Valencia.
%   Contact: jorge.vicent@uv.es
%   $Revision: 1.04 $  $Date: 2019/04/02 $

filename = [alg.GenConf.filename,'.h5'];

if ~isempty(LUTheader)
    hdr = readLUThdr(filename); oldLUTheader = hdr.LUTheader;
    
    start = [1,size(oldLUTheader,2)+1]; count = size(LUTheader);
    h5write(filename,'/LUTheader',LUTheader,start,count);
end

if ~isempty(wvl) && ~isempty(I0) && ~isempty(outvarnames)
    %% Print output variable names: "* Output variable name"
    aux1 = [];
    for i=1:numel(outvarnames)
    	i1 = findstr(outvarnames{i},'(');
        i2 = findstr(outvarnames{i},')');
        aux1 = [aux1,',',outvarnames{i}(i1+1:i2-1)];
    end
    aux1(1) = [];
    h5writeatt(filename,'/','outnames',aux1)
    %% Print wavelengths:
    h5create(filename,'/wvl',[numel(wvl) 1]);
    h5write(filename,'/wvl',wvl)
    h5writeatt(filename,'/wvl','Name','Wavelength')
	h5writeatt(filename,'/wvl','Units','nm')
    
    %% Print solar irradiance:
    h5create(filename,'/I0',[numel(I0) 1]);
    h5write(filename,'/I0',I0)
    h5writeatt(filename,'/I0','Name','Solar irradiance')
    h5writeatt(filename,'/I0','Units','mW/m2/nm')
end



