function TF = myisoutlier(A)
% MYISOUTLIER returns a logical array TF whose elements are true when an 
% outlier is detected in the corresponding element of A. By default, an 
% outlier is a value that is more than ten scaled median absolute 
% deviations (MAD) away from the median. 
% If A is a matrix, then isoutlier operates on each column separately.
%
% INPUTs: file1 and file2 = input tape7 files
%         RHO1 and RHO2 = constant reflectivities associated with the
%                         simulations on file1 and file2
%         SZA = Sun Zenith Angle
%
% OUTPUTs: lambda = Wavelength in [nm]
%          Lp0 = Atmospheric path radiance
%          Edir = Direct flux
%          Edif = Diffuse flux
%          S = Spherical Albedo
%          tdir = Direct transmittance
%          tdif = Diffuse transmittance
%
%   Based on MATLAB R2017b function ISOUTLIER
%

%   Copyright 2017 Image Processing Laboratory (IPL), Univ. of Valencia.
%   Contact: jorge.vicent@uv.es
%   $Revision: 1.00 $  $Date: 2017/07/28 $

% Scaled Mean Absolut Deviation (MAD):
s = (-1/(sqrt(2)*erfcinv(3/2)));
MAD = nanmedian(abs(bsxfun(@minus,A,nanmedian(A))))*s;

TF = logical(zeros(size(A)));
for i=1:size(A,2)
    TF(:,i) = A(:,i) - nanmedian(A(:,i)) > 10*MAD(i);
end