function [] = plotresults(filename,errormap,LUTheader,iter)
% Plotthe 2D interpolation error maps for the TGARS paper.
fontname = 'Helvetica'; fontsize = 23; fontunits = 'points';
set(0,'DefaultAxesFontName',fontname,'DefaultAxesFontSize',fontsize,'DefaultAxesFontUnits',fontunits,...
     'DefaultTextFontName',fontname,'DefaultTextFontSize',fontsize,'DefaultTextFontUnits',fontunits,...
     'DefaultLineLineWidth',0.5,'DefaultLineMarkerSize',15,'DefaultLineColor',[0 0 1],'DefaultAxesVisible','on');


hdr = readLUThdr([filename,'.hdr']); X = hdr.LUTheader;

GenConf = read_LUTconfig([filename,'.xml'],'GenConf');

refldb  = str2num(GenConf.refldb); clear GenConf
rho     = csvread(['..',filesep,'Others',filesep,'refldb.txt']);
rho     = spline(rho(:,1),rho(:,refldb),hdr.wvl);
Y       = h5read([filename,'.h5'],'/LUTdata');

sz = size(X,2); ini = 2^size(X,1);

lb = min(X(:,1:ini),[],2); ub = max(X(:,1:ini),[],2);
num = round(10*sz^(1/size(X,1))); aux = cell(1,size(X,1));
for i=1:size(X,1), aux{i} = lb(i)+(0:num)*(ub(i)-lb(i))/num; end
[aux{:}] = ndgrid(aux{:}); XI = zeros(size(X,1),(1+num)^size(X,1));
for i=1:size(X,1), XI(i,:) = aux{i}(:); end
maxerror = myinterpn(X,errormap,XI,'matlablinear'); maxerror(maxerror<0) = 0;

asd = reshape(maxerror,1+num,1+num);
asd = log10(asd);

valfile = ['E:',filesep,'Mis Documentos D',filesep,'Modtran LUTGen',filesep,'Publications',filesep,'',...
                 'Papers',filesep,'TGARS - Gradient-based Automatic LUT generation',filesep,'',...
                 'data',filesep,'valCase1'];
hdr     = readLUThdr([valfile,'.hdr']); Xtrue = hdr.LUTheader;
xlabelstr = 'SZA (deg)'; ylabelstr = 'AOT (-)'; % CASE #1
% xlabelstr = '\alpha (-)'; ylabelstr = 'g_{HG} (-)'; % CASE #2


cmap = 'hot';
cxs  = log10([0.01 0.6]);
% cxs = [0.1 0.6];
ccol = [75 155 180]/255; trinodes = ccol; ncol = 0.3*[1 1 1];

fh = figure(10); set(gcf,'tag','plotfig')
h1 = subplot(1,2,1);
    imagesc(lb(2)+(0:num)*(ub(2)-lb(2))/num,lb(1)+(0:num)*(ub(1)-lb(1))/num,asd)
    colormap(cmap), caxis(cxs)
    hold on
    plot(X(2,:),X(1,:),'x','color',ccol,'linewidth',1.5)
    minX = min(X,[],2);                         maxX = max(X,[],2);
    M    = 1./(maxX-minX);                      N    = -minX.*M;
    X1   = bsxfun(@plus,bsxfun(@times,X,M),N);  tri  = delaunayn(X1');
    triplot(tri,X(2,:),X(1,:),'color',trinodes)
    plot(LUTheader(2,:),LUTheader(1,:),'o','color',ncol,'linewidth',2,'markersize',10)
    hold off
    xlim([min(Xtrue(2,:)),max(Xtrue(2,:))]), ylim([min(Xtrue(1,:)),max(Xtrue(1,:))])
    xlabel(xlabelstr), ylabel(ylabelstr), title('{\itCross-validation} error map')
h2 = subplot(1,2,2);
    Ytrue     = h5read([valfile,'.h5'],'/LUTdata');
    LTOA_true = LUT2TOA(valfile,Ytrue,rho,1:size(Ytrue,2));
    YI        = myinterpn(X,Y,Xtrue,'matlablinear');
    LTOA      = LUT2TOA(valfile,YI,rho,1:size(Ytrue,2));
    auxerror  = 100*abs(LTOA - LTOA_true)./LTOA_true;
    TF = myisoutlier(auxerror); auxerror(TF) = nan; % Remove outliers
    errormap = max(auxerror);
    asd       = reshape(errormap,numel(unique(Xtrue(1,:))),numel(unique(Xtrue(2,:))));
    asd = log10(asd);
    imagesc(Xtrue(2,:),Xtrue(1,:),asd)
    colormap(cmap), caxis(cxs)
    hold on
    plot(X(2,:),X(1,:),'x','color',ccol,'linewidth',1.5)
    plot(LUTheader(2,:),LUTheader(1,:),'o','color',ncol,'linewidth',2,'markersize',10)
    xx=reshape(Xtrue(2,:),100,100); yy=reshape(Xtrue(1,:),100,100);
    contour(xx,yy,asd,log10([0.2 0.2]),'k','linewidth',1)
    hold off
    xlim([min(Xtrue(2,:)),max(Xtrue(2,:))]), ylim([min(Xtrue(1,:)),max(Xtrue(1,:))])
    xlabel(xlabelstr), ylabel(ylabelstr), title('{\itTrue} error map')
    colb = colorbar('YTick',log10([0.01 0.02 0.05 0.1 0.2 0.5]),'YTickLabel',[0.01 0.02 0.05 0.1 0.2 0.5]);
%     colb = colorbar('YTick',[0.1 0.2 0.3 0.4 0.5 0.6],'YTickLabel',[0.1 0.2 0.3 0.4 0.5 0.6]);
    ylabel(colb,'Relative error (%)')

set(h1,'position', [0.055 0.21 0.40 0.69]); set(h2,'position', [0.518 0.21 0.40 0.69]);
set(gcf,'PaperUnits','centimeters','PaperPosition',[0 0 50 15],'units','centimeters')
hl=legend('Current nodes','Added nodes');
set(hl,'fontsize',20,'orientation','horizontal','color',0.85*[1 1 1],'position',[0.5 0.05 0 0])
set(gcf,'units','pixels'), pos=get(gcf,'position');
set(gcf,'PaperUnits','centimeters','PaperPosition',[0 0 50 15])
figfile = [strrep(valfile,'data','figs'),'_',num2str(iter)];
print(fh,'-depsc',[figfile,'.eps']), print(fh,'-dpng',[figfile,'.png'])

end