classdef MODTRAN6<ALG
    %MODTRAN5 Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
        
    end
    
    methods
        function this=MODTRAN6(LUTconffile,RTMconffile)
            this = this@ALG(LUTconffile,RTMconffile);
        end
    end
    
    methods % Functions for preparing input files        
        % Write collection of MODTRAN input files
        function writeInputs(this,h)
            % Number of parallel RTM executions
            Nparallel = str2num(this.GenConf.parallel);
            % Total number of LUT nodes
            Ncomb = this.numberCombinations();
            if Ncomb<Nparallel, Nparallel = Ncomb; end
            ratio = Ncomb/Nparallel;

            % Loop for the number of parallel executions of the RTM:
            for i = 1:Nparallel
                % Make sub-directories where to store RTM data:
                this.makesubdir(i)
                
                % Create JSON files:                
                if i==Nparallel, extra = (ratio-floor(ratio))*Nparallel;
                else,            extra = 0;
                end
                
                % Loop for each combination (at each block of parallel execution):                    
                for j=(i-1)*floor(ratio)+1:i*floor(ratio)+extra
                	waitbar((j-(i-1)*floor(ratio)+1)/floor(ratio),h,['Writing ',this.GenConf.RTMname,' json files'])
                    jsonname = ['comb',num2str(j)];
                    if isempty(this.LUTheader)
                    	inputs = this.inputs0;
                    else
                    	inputs  = [this.inputs0;num2cell(this.LUTheader(:,j))];
                    end
                    if isstruct(this.AER) % Checks if OPAC or user-defined aerosol are used in LUT
                    	% Convert input Aerosol model into OPAC or user-defined
                        % aerosol parameters:
                        if inputs{this.AER.ind}<0 || inputs{this.AER.ind}>10
                        	% Aerosol model for current simulation is OPAC or user-defined
                            inputs{alg.AER.ind} = alg.AER.opticalProp(this.AER.aerIDs==inputs{this.AER.ind});
                        end
                    end
                    if isstruct(this.ATM) % Checks if user-defined atmosphere are used in LUT
                    	% Convert input Atmospheric model into user-defined
                        % atmosphere parameters:
                        if inputs{this.ATM.ind}<0 || inputs{this.ATM.ind}>10
                        	% Aerosol model for current simulation is OPAC or user-defined
                            inputs{this.ATM.ind} = this.ATM.profiles(this.ATM.atmIDs==inputs{this.ATM.ind});
                        end
                    end
                    % Check operation mode and computation of outputs:
                    % Transfer Function + 2-streams MODTRAN Interrogation
                    % Tech. (Guanter et al. 2009)
                    if strcmp(this.GenConf.op_mode,'Transfer Functions') && strcmp(this.AdvConf.DISALB,'F')
                        auxVarnames = this.varnames; auxVarnames{end+1} = 'IEMSCT';
                        auxInputs = inputs; auxInputs{end+1} = 2;
                    	this.writeRTMinput([this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,jsonname,'rhop5.json'],0.5,auxVarnames,auxInputs,this.SpeConf,'toa');
                        this.writeRTMinput([this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,jsonname,'rhop15.json'],0.15,auxVarnames,auxInputs,this.SpeConf,'toa');
                    
                    % Transfer Function + DISALB option 'ON'
                    elseif strcmp(this.GenConf.op_mode,'Transfer Functions') && strcmp(this.AdvConf.DISALB,'T')
                        auxVarnames = this.varnames; auxVarnames{end+1} = 'IEMSCT';
                        auxInputs = inputs; auxInputs{end+1} = 2;
                    	this.writeRTMinput([this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,jsonname,'.json'],0,auxVarnames,auxInputs,this.SpeConf,'toa');
                   
                    % Transfer Function + 4-streams MODTRAN Interrogation
                    % Tech. (Verhoef et al. 2012)
                    elseif strcmp(this.GenConf.op_mode,'Transfer Functions') && strcmp(this.AdvConf.DISALB,'W')
                        auxVarnames = this.varnames; auxVarnames{end+1} = 'IEMSCT';
                        auxInputs = inputs; auxInputs{end+1} = 2;
                        this.writeRTMinput([this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,tp5name,'toa0.tp5'],0,auxVarnames,auxInputs,this.SpeConf,'toa');
                        this.writeRTMinput([this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,tp5name,'boap5.tp5'],0.5,auxVarnames,auxInputs,this.SpeConf,'boa');
                        this.writeRTMinput([this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,tp5name,'boa1.tp5'],1,auxVarnames,auxInputs,this.SpeConf,'boa');
                        this.writeRTMinput([this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,tp5name,'toa1.tp5'],1,auxVarnames,auxInputs,this.SpeConf,'toa');

                        fprintf(fid,'%-256s\n',['tape',filesep,tp5name,'toa0.tp5']);
                        fprintf(fid,'%-256s\n',['tape',filesep,tp5name,'boap5.tp5']);
                        fprintf(fid,'%-256s\n',['tape',filesep,tp5name,'boa1.tp5']);
                        fprintf(fid,'%-256s\n',['tape',filesep,tp5name,'toa1.tp5']);

                    % Transmittance:
                    elseif strcmp(this.GenConf.op_mode,'Transmittance')
                    	auxVarnames = this.varnames; auxVarnames{end+1} = 'IEMSCT';
                        auxInputs = inputs; auxInputs{end+1} = 0;
                        this.writeRTMinput([this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,jsonname,'.json'],0,auxVarnames,auxInputs,this.SpeConf,'toa');
                    end
                end
            end
            close(h)
        end
        
        % Make sub-folders where to store MODTRAN files
        function makesubdir(this,i)
            % Make sub-directories where to store MODTRAN data:
            mkdir([this.GenConf.filename,'_',num2str(i)])         % Main sub-directory
            mkdir([this.GenConf.filename,'_',num2str(i),filesep,'tape']) % MODTRAN I/O sub-directory
        end
        
        % Run MODTRAN RTM
        runRTM(this,parspmb)
    end
    
    methods % Functions to create LUT file
        % Create LUT file by reading MODTRAN output files
        function createLUTfile(this,iter)
            % Read LUT header
            hdr       = readLUThdr([this.GenConf.filename,'.h5']);
            this.LUTheader = hdr.LUTheader;
             % Number of parallel RTM executions
            Nparallel = str2num(this.GenConf.parallel);
            % Total number of LUT nodes
            Ncomb = this.numberCombinations();
            
            % The operation mode indicates how the data should be read from the RTM
            % output files in order to generate the data for the LUT:

            h = waitbar(0,'','Name','Populating LUT file. Please wait...');
            color = [0.5 0 0]; set(findobj(h,'type','patch'),'facecolor',color);

            if iter>0
                info  = h5info([this.GenConf.filename,'.h5'], '/LUTdata');
                n     = info.Dataspace.Size(2);
                Ncomb = Ncomb - n;
            else
                n     = 0;
            end
            % Total number of LUT nodes
            if Ncomb<Nparallel, Nparallel = Ncomb; end
            ratio = Ncomb/Nparallel;
            
            % The advanced configuration parameter DISALB for MODTRAN5 also
            % indicates how the RTM output data should be read to generate the 
            % data for the LUT:
            DISALB = this.AdvConf.DISALB;

            % Get value of SZA from default of in LUT header:
            SZA = hdr.SZA;
            if numel(SZA)>1
                SZA = SZA(n+1:end);
            else
                SZA = SZA*ones(1,size(hdr.LUTheader,2));
            end            
            
            for i=1:Nparallel
                 if i==Nparallel, extra = (ratio-floor(ratio))*Nparallel;
                 else extra=0;
                 end
                % Loop for each combination (at each block of parallel execution):
                for j=(i-1)*floor(ratio)+1:i*floor(ratio)+extra
                    waitbar((j-(i-1)*floor(ratio)+1)/floor(ratio),h,'Populating LUT file. Please wait...')
                    tp7name = ['comb',num2str(j)];
                    % Check operation mode and computation of outputs:
                    % Transfer Function + 2-streams MODTRAN Interrogation Tech.
                    if strcmp(this.GenConf.op_mode,'Transfer Functions') && strcmp(DISALB,'F')
                        file1 = [this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,tp7name,'rhop5.tp7'];
                        file2 = [this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,tp7name,'rhop15.tp7'];
                        [lambda,Lp0,Edir0,Edif0,S,tdir,tdif,I0] = this.tp7_to_LUT(file1,file2,0.5,0.15,SZA(j));
                        delete(file1,file2) % Delete files once they are read
                        % Save data into LUT hdf5 file:
                        if (i==1 && j==1) && (isempty(iter) || iter==0)
                            if isempty(iter)
                                % LUT file is created without possibility
                                % of being expanded ==> no chunking
                                h5create([this.GenConf.filename,'.h5'],'/LUTdata',[6*numel(lambda) Ncomb]);
                            elseif iter==0
                                % LUT file will be expanded in next
                                % iteration ==> define chunking
                                h5create([this.GenConf.filename,'.h5'],'/LUTdata',[6*numel(lambda) Inf],'ChunkSize',[6*numel(lambda) Ncomb]);
                            end
                            outvarnames = {'Path Radiance (Lp0) [mW/m2/sr/nm]',...
                                           'At-surface direct (Edir0) irradiance [mW/m2/nm]',...
                                           'At-surface diffuse irradiance (Edif0) [mW/m2/nm]',...
                                           'Spherical albedo (S) [-]',...
                                           'Direct upwards transmittance (tdir) [-]',...
                                           'Diffuse upwards transmittance (tdif) [-]'};
                            this.updateLUThdr(lambda,I0,outvarnames,[])
                        end
                        start = [1,j+n];
                        count = [6*numel(lambda) 1];
                        h5write([this.GenConf.filename,'.h5'], '/LUTdata',[Lp0;Edir0;Edif0;S;tdir;tdif],start,count);

                    % Transfer Function + DISALB option 'ON'
                    elseif strcmp(this.GenConf.op_mode,'Transfer Functions') && strcmp(DISALB,'T')
                        file1 = [this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,tp7name,'.acd'];
                        [lambda,Lp0,Edir0,Edif0,S,tdir,tdif,I0] = Read_acd(file1,SZA(j));
                        delete(file1) % Delete file once they are read
                        % Save data into LUT hdf5 file:
                        if (i==1 && j==1) && (isempty(iter) || iter==0)
    %                         h5create([GenConf.filename,'.h5'],'/LUTdata',[6*numel(lambda) Ncomb]);
                            h5create([this.GenConf.filename,'.h5'],'/LUTdata',[6*numel(lambda) Inf],'ChunkSize',[6*numel(lambda) Ncomb]);
                            outvarnames = {'Path Radiance (Lp0) [mW/m2/sr/nm]',...
                                           'At-surface direct (Edir0) irradiance [mW/m2/nm]',...
                                           'At-surface diffuse irradiance (Edif0) [mW/m2/nm]',...
                                           'Spherical albedo (S) [-]',...
                                           'Direct upwards transmittance (tdir) [-]',...
                                           'Diffuse upwards transmittance (tdif) [-]'};
                            this.updateLUThdr(lambda,I0,outvarnames,[])
                        end
                        start = [1,j+n];
                        count = [6*numel(lambda) 1];
                        h5write([this.GenConf.filename,'.h5'], '/LUTdata',[Lp0;Edir0;Edif0;S;tdir;tdif],start,count);

                    % Transfer Function + 4-streams MODTRAN Interrogation Tech.
                    elseif strcmp(this.GenConf.op_mode,'Transfer Functions') && strcmp(DISALB,'W')
                        files{1} = [this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,tp7name,'toa0.tp7'];
                        files{2} = [this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,tp7name,'boap5.tp7'];
                        files{3} = [this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,tp7name,'boa1.tp7'];
                        files{4} = [this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,tp7name,'toa1.tp7'];
                        [lambda,Lp0,Edir0,Edif0,S,tdir,tdif,I0] = this.tp7_to_LUT2(files,[0,0.5,1,1],SZA(j));
                        delete(files{1},files{2},files{3},files{4}) % Delete files once they are read
                        % Save data into LUT hdf5 file:
                        if (i==1 && j==1) && (isempty(iter) || iter==0)
                            if isempty(iter)
                                % LUT file is created without possibility
                                % of being expanded ==> no chunking
                                h5create([this.GenConf.filename,'.h5'],'/LUTdata',[6*numel(lambda) Ncomb]);
                            elseif iter==0
                                % LUT file will be expanded in next
                                % iteration ==> define chunking
                                h5create([this.GenConf.filename,'.h5'],'/LUTdata',[6*numel(lambda) Inf],'ChunkSize',[6*numel(lambda) Ncomb]);
                            end
                            outvarnames = {'Path Radiance (Lp0) [mW/m2/sr/nm]',...
                                           'At-surface direct (Edir0) irradiance [mW/m2/nm]',...
                                           'At-surface diffuse irradiance (Edif0) [mW/m2/nm]',...
                                           'Spherical albedo (S) [-]',...
                                           'Direct upwards transmittance (tdir) [-]',...
                                           'Diffuse upwards transmittance (tdif) [-]'};
                            this.updateLUThdr(lambda,I0,outvarnames,[])
                        end
                        start = [1,j+n];
                        count = [6*numel(lambda) 1];
                        h5write([this.GenConf.filename,'.h5'], '/LUTdata',[Lp0;Edir0;Edif0;S;tdir;tdif],start,count);

                    % Transmittance mode:    
                    elseif strcmp(this.GenConf.op_mode,'Transmittance')
                        file1 = [this.GenConf.filename,'_',num2str(i),filesep,'tape',filesep,tp7name,'.tp7'];
                        [lambda,Ttot,Tgas] = this.readRTMoutput(file1);
                        delete(file1) % Delete file once they are read
                        % Save data into LUT hdf5 file:
                        if (i==1 && j==1) && (isempty(iter) || iter==0)
    %                         h5create([GenConf.filename,'.h5'],'/LUTdata',[15*numel(lambda) Ncomb]);
                            h5create([this.GenConf.filename,'.h5'],'/LUTdata',[15*numel(lambda) Inf],'ChunkSize',[15*numel(lambda) Ncomb]);
                            outvarnames = {'Total transmittance (Ttot) [-]',...
                                           'H2O transmittance (Th2o) [-]',...
                                           'O3 transmittance (To3) [-]',...
                                           'N2 transmittance (Tn2) [-]',...
                                           'Aerosol+Clouds transmittance (Taer) [-]',...
                                           'HNO3 transmittance (Thno3) [-]',...
                                           'CO2 transmittance (Tco2) [-]',...
                                           'CO transmittance (Tco) [-]',...
                                           'CH4 transmittance (Tch4) [-]',...
                                           'N2O transmittance (Tn2o) [-]',...
                                           'O2 transmittance (To2) [-]',...
                                           'NH3 transmittance (Tnh3) [-]',...
                                           'NO transmittance (Tno) [-]',...
                                           'NO2 transmittance (Tno2) [-]',...
                                           'SO2 transmittance (Tso2) [-]'};
                            this.updateLUThdr(lambda,nan,outvarnames,[])
                        end
                        start = [1,j+n];
                        count = [15*numel(lambda) 1];
                        h5write([this.GenConf.filename,'.h5'], '/LUTdata',[Ttot;reshape(Tgas,[14*numel(lambda) 1])],start,count);
                    end
                end
            end
            close(h)
        end
        
        % Convert 2 MODTRAN output files in atmospheric transfer functions
        % (based on Guanter et al. 2009)
        [lambda,Lp0,Edir0,Edif0,S,tdir,tdif,I0] = ...
            tp7_to_LUT(this,file1,file2,rho1,rho2,SZA);
        
        % Convert 4 MODTRAN output files in atmospheric transfer functions
        % (based on Verhoef et al. 2012)
        [lambda,Lp0,Edir0,Edif0,S,tdir,tdif,I0] = ...
            tp7_to_LUT2(this,files,rhos,SZA);
        
        % Read MODTRAN DISALB option file (.acd)
        [wvl,Lp0,Edir0,Edif0,S,tdir,tdif,I0] = ...
            Read_acd(this,acdfile,SZA);
    end
    
    methods(Static)
        % Write MODTRAN input file
        writeRTMinput(file,rho,varnames,inputval,SpeConf,flag);
        
        % Read MODTRAN output file
        [wvl,Tdir,DRCT_RFLT,GRND_RFLT,SOL_SCAT,EXTIRR,SURFEM,PTHTHRML,TOTRAD] = ...
            readRTMoutput(file); 
    end
end

