classdef libRadtran<ALG
    %MODTRAN5 Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
        
    end
    
    methods
        function this=libRadtran(LUTconffile,RTMconffile)
            this = this@ALG(LUTconffile,RTMconffile);
        end
    end
    
    methods % Functions for preparing input files        
        function writeInputs(this,h)
            % Number of parallel RTM executions
            Nparallel = str2num(this.GenConf.parallel);
            % Total number of LUT nodes
            Ncomb = this.numberCombinations();
            if Ncomb<Nparallel, Nparallel = Ncomb; end
            ratio = Ncomb/Nparallel;

            % Loop for the number of parallel executions of the RTM:
            for i = 1:Nparallel
                % Make subdirectory where to store RTM data:
                this.makesubdir(i)
                
                % Create .INP files:                
                if i==Nparallel, extra = (ratio-floor(ratio))*Nparallel;
                else,            extra = 0;
                end
                
                % Loop for each combination (at each block of parallel execution):
                for j=(i-1)*floor(ratio)+1:i*floor(ratio)+extra
                    waitbar((j-(i-1)*floor(ratio)+1)/floor(ratio),h,['Writing ',this.GenConf.RTMname,' input files'])
                    inputname = ['comb',num2str(j)];
                    if isempty(this.LUTheader)
                        inputs = this.inputs0;
                    else
                        inputs  = [this.inputs0;num2cell(this.LUTheader(:,j))];
                    end
                    if isstruct(this.AER) % Checks if OPAC or user-defined aerosol are used in LUT
                        % Convert input Aerosol model into OPAC or user-defined
                        % aerosol parameters:
                        if inputs{this.AER.ind}<0 || inputs{this.AER.ind}>10
                            % Aerosol model for current simulation is OPAC or user-defined
                            inputs{this.AER.ind} = this.AER.opticalProp(this.AER.aerIDs==inputs{this.AER.ind});
                        end
                    end
                    if isstruct(this.ATM) % Checks if user-defined atmosphere are used in LUT
                        % Convert input Atmospheric model into user-defined
                        % atmosphere parameters:
                        if inputs{this.ATM.ind}<0 || inputs{this.ATM.ind}>10
                            % Aerosol model for current simulation is OPAC or user-defined
                            inputs{this.ATM.ind} = this.ATM.profiles(this.ATM.atmIDs==inputs{this.ATM.ind});
                        end
                    end
                    % Write file to extract solar irradiance. Only one file
                    % for the entire LUT:
                    if i==1 && j==1
                        this.writeRTMinput([this.GenConf.filename,'_irr.inp'],0,this.varnames,inputs,this.SpeConf,'irr');
                    end
                    % Check operation mode and computation of outputs:
                    % Transfer Function + 5-streams libRadtran Interrogation Tech.
                    if strcmp(this.GenConf.op_mode,'Transfer Functions')
                        this.writeRTMinput([this.GenConf.filename,'_',num2str(i),filesep,inputname,'toa0.inp'],0,this.varnames,inputs,this.SpeConf,'toa'); % For path radiance
                        this.writeRTMinput([this.GenConf.filename,'_',num2str(i),filesep,inputname,'boa0.inp'],0,this.varnames,inputs,this.SpeConf,'boa'); % For direct and diffuse at-surface irradiance
                        this.writeRTMinput([this.GenConf.filename,'_',num2str(i),filesep,inputname,'boap3.inp'],0.3,this.varnames,inputs,this.SpeConf,'boa'); % For spherical albedo
                        if inputs{strcmp(this.varnames,'ZOUT')}==100
                            % Satellite sensor. Direct and diffuse
                            % components of transmittance given reciprocity
                            % principle
                            this.writeRTMinput([this.GenConf.filename,'_',num2str(i),filesep,inputname,'recip.inp'],0,this.varnames,inputs,this.SpeConf,'recip'); % For direct and diffuse target-to-sensor transmittance
                        else % Airborne sensor. Only Total transmittance
                            this.writeRTMinput([this.GenConf.filename,'_',num2str(i),filesep,inputname,'toap5.inp'],0.5,this.varnames,inputs,this.SpeConf,'toa'); % For total target-to-sensor transmittance
                        end
                    end
                end
            end
            close(h)
        end
        
        function makesubdir(this,i)
            % Make sub-directories where to store libRadtran data:
            mkdir([this.GenConf.filename,'_',num2str(i)])         % Main sub-directory
        end
        
        runRTM(this,parspmb)
    end
    
    methods % Functions to create LUT file
        % Create LUT file by reading libRadtran output files
        function createLUTfile(this,iter)
            % Read LUT header
            hdr       = readLUThdr([this.GenConf.filename,'.h5']);
            this.LUTheader = hdr.LUTheader;
             % Number of parallel RTM executions
            Nparallel = str2num(this.GenConf.parallel);
            % Total number of LUT nodes
            Ncomb = this.numberCombinations();
            
            % The operation mode indicates how the data should be read from the RTM
            % output files in order to generate the data for the LUT:

            h = waitbar(0,'','Name','Populating LUT file. Please wait...');
            color = [0.5 0 0]; set(findobj(h,'type','patch'),'facecolor',color);

            if iter>0
                info  = h5info([this.GenConf.filename,'.h5'], '/LUTdata');
                n     = info.Dataspace.Size(2);
                Ncomb = Ncomb - n;
            else
                n     = 0;
            end
            % Total number of LUT nodes
            if Ncomb<Nparallel, Nparallel = Ncomb; end
            ratio = Ncomb/Nparallel;

            % Get value of SZA from default of in LUT header:
            SZA = hdr.SZA;
            if numel(SZA)>1
                SZA = SZA(n+1:end);
            else
                SZA = SZA*ones(1,size(hdr.LUTheader,2));
            end    
            
            % Find whether simulations are for airborne or satellite level:
            toa = true;
            fn = fieldnames(hdr.dynamic);
            if ~isempty(find(strcmp(fn,'ZOUT')))
                if any(hdr.dynamic.ZOUT.value<100), toa = false; end
            elseif hdr.static.ZOUT.value<100
                toa = false;
            end 
            
            for i=1:Nparallel
                 if i==Nparallel, extra = (ratio-floor(ratio))*Nparallel;
                 else extra=0;
                 end
                % Loop for each combination (at each block of parallel execution):
                for j=(i-1)*floor(ratio)+1:i*floor(ratio)+extra
                    waitbar((j-(i-1)*floor(ratio)+1)/floor(ratio),h,'Populating LUT file. Please wait...')
                    outputname = ['comb',num2str(j)];
                    % Extract solar irradiance. Only one file for the 
                    % entire LUT:
                    if i==1 && j==1
                        aux = dir([this.GenConf.filename,'_irr_*.out']);
                        I0  = [];
                        for k=1:numel(aux) % Loop for each spectral band
                            file = [this.GenConf.filename,'_irr_band',num2str(k),'.out'];
                            [~,auxI0] = this.readRTMoutput(file);
                            I0   = [I0;auxI0];
                            delete(file)
                        end
                        I0 = I0/cosd(SZA(1));
                    end
                    % Check operation mode and computation of outputs:
                    % Transfer Function + 3-streams libRadtran Interrogation Tech.
                    if strcmp(this.GenConf.op_mode,'Transfer Functions')
                        aux = dir([this.GenConf.filename,'_',num2str(i),filesep,outputname,'toa0_*.out']);
                        lambda = [];    Lp0 = [];   Edir0 = [];
                        Edif0  = [];    S   = [];
                        if toa, tdir  = []; tdif   = [];
                        else Ttot = [];
                        end
                        for k=1:numel(aux) % Loop for each spectral band
                            files{1} = [this.GenConf.filename,'_',num2str(i),filesep,outputname,'toa0_band',num2str(k),'.out'];
                            files{2} = [this.GenConf.filename,'_',num2str(i),filesep,outputname,'boa0_band',num2str(k),'.out'];
                            files{3} = [this.GenConf.filename,'_',num2str(i),filesep,outputname,'boap3_band',num2str(k),'.out'];
                            if toa
                                files{4} = [this.GenConf.filename,'_',num2str(i),filesep,outputname,'recip_band',num2str(k),'.out'];
                                [auxlambda,auxLp0,auxEdir0,auxEdif0,auxS,auxtdir,auxtdif] = this.out_to_LUT(files,[0.3 0.5],SZA(j));
                                tdir   = [tdir;auxtdir];
                                tdif   = [tdif;auxtdif];
                            else
                                files{4} = [this.GenConf.filename,'_',num2str(i),filesep,outputname,'toap5_band',num2str(k),'.out'];
                                [auxlambda,auxLp0,auxEdir0,auxEdif0,auxS,auxTtot] = this.out_to_LUT(files,[0.3 0.5],SZA(j));
                                Ttot   = [tdir;auxTtot];
                            end
                            lambda = [lambda;auxlambda];
                            Lp0    = [Lp0;auxLp0];
                            Edir0  = [Edir0;auxEdir0];
                            Edif0  = [Edif0;auxEdif0];
                            S      = [S;auxS];
                        end
                        % Detect lambda=300 nm and 550.555 (used to set the
                        % AOT value at 550 nm) and remove from the vector.
                        % WARNING if interested in simulation in the UV range!!!
                        idx = lambda==300 | lambda==550.555;
                        idx = lambda==300 | lambda==550.555;
                        lambda(idx)=[]; Lp0(idx)=[];  Edir0(idx)=[];
                        Edif0(idx)=[]; S(idx)=[];
                        if toa, tdir(idx)=[]; tdif(idx)=[];
                        else Ttot(idx)=[];
                        end
                        delete(files{1},files{2},files{3},files{4}) % Delete files once they are read
                        % Save data into LUT hdf5 file:
                        if (i==1 && j==1) && (isempty(iter) || iter==0)
                            I0(idx)=[];
                            if isempty(iter)
                                % LUT file is created without possibility
                                % of being expanded ==> no chunking
                                h5create([this.GenConf.filename,'.h5'],'/LUTdata',[6*numel(lambda) Ncomb]);
                            elseif iter==0
                                % LUT file will be expanded in next
                                % iteration ==> define chunking
                                h5create([this.GenConf.filename,'.h5'],'/LUTdata',[6*numel(lambda) Inf],'ChunkSize',[6*numel(lambda) Ncomb]);
                            end
                            outvarnames = {'Path Radiance (Lp0) [mW/m2/sr/nm]',...
                                           'At-surface direct (Edir0) irradiance [mW/m2/nm]',...
                                           'At-surface diffuse irradiance (Edif0) [mW/m2/nm]',...
                                           'Spherical albedo (S) [-]',...
                                           'Direct upwards transmittance (tdir) [-]',...
                                           'Diffuse upwards transmittance (tdif) [-]'};
                            if ~toa
                                outvarnames{5}='Total upwards transmittance (Ttot) [-]';
                                outvarnames(6)=[];
                            end
                                
                            this.updateLUThdr(lambda,I0,outvarnames,[])
                        end
                        start = [1,j+n];
                        if toa
                            count = [6*numel(lambda) 1];
                            h5write([this.GenConf.filename,'.h5'],'/LUTdata',[Lp0;Edir0;Edif0;S;tdir;tdif],start,count);
                        else
                            count = [5*numel(lambda) 1];
                            h5write([this.GenConf.filename,'.h5'],'/LUTdata',[Lp0;Edir0;Edif0;S;Ttot],start,count);
                        end
                        

                    % Cloud TOA radiance mode:    
                    elseif strcmp(this.GenConf.op_mode,'Cloud TOA radiance',this.GenConf.op_mode,DISALB)

                    end
                end
            end
            close(h)
        end
        
        % Convert libRadtran .out files in atmospheric transfer functions
        [lambda,Lp0,Edir0,Edif0,S,T1,T2] = out_to_LUT(this,files,rho,SZA);
    end
    
    methods(Static)
         % Write libRadtran input file
        writeRTMinput(file,rho,varnames,inputval,SpeConf,flag);
        
        % Read libRadtran output file
        [wvl,Edr,Edn,Eup,Ltoa] = readRTMoutput(file);    
    end
end

