function [wvl,varargout] = readRTMoutput(outfile)
%READRTMOUTPUT Read libRadtran output .out file
%   [WVL,EDR,EDN,EUP,LTOA] = READRTMOUTPUT(OUTFILE) reads libRadtran output
%   .out file (OUTFILE) and generates the following output variables:
%   WVL  - Wavelength (in [nm]) at which the output data is given
%   EDR  - Downwards direct solar irradiance (in [mW/m^2/nm]) %REVIEW!!
%   EDN  - Downwards diffuse solar irradiance (in [mW/m^2/nm]) %REVIEW!!
%   EUP  - Upwards diffuse solar irradiance (in [mW/m^2/nm]) %REVIEW!!
%   LTOA - At-sensor radiance (in [mW/m^2/sr/nm]) %REVIEW!!
%   
%   Alternatively,
%   [WVL,I0] = READRTMOUTPUT(OUTFILE) reads libRadtran output .out file 
%   (OUTFILE) and generates the following output variables:
%   WVL  - Wavelength (in [nm]) at which the output data is given
%   I0   - Extraterrestial solar irradiance (in [mW/m^2/nm]) %REVIEW!!
%
%   Based on internal communication with C. Emde (27/02/2019).
%
%   See also: LUTGEN_PROCESS, OUT_TO_LUT

%   Copyright 2019 Image Processing Laboratory (IPL), Univ. of Valencia.
%   Contact: jorge.vicent@uv.es
%   $Revision: 1.00 $  $Date: 2019/03/16 $

%% Open File:
data = importdata(outfile);

wvl  = data(:,1); % Wavelength in [nm]
if size(data,2)==2
    varargout{1} = data(:,2); % Solar irradiance
else
    varargout{1} = data(:,2); % Downwards direct solar irradiance [mW/m^2/nm]
    varargout{2} = data(:,3); % Downwards diffuse solar irradiance [mW/m^2/nm]
    varargout{3} = data(:,4); % Upwards diffuse solar irradiance [mW/m^2/nm]
    varargout{4} = data(:,5); % At-sensor radiance [mW/m^2/sr/nm]
end

% END of function
end
