function [] = runRTM(alg,parspmb)
cellfind = @(string)(@(cell_contents)(strcmp(string,cell_contents)));

% Once the input files are generated, the atmospheric RTM is run for each
% combination of key input atmospheric parameters. This step considers the
% possibility of multithreading

comp = computer;
switch comp
    case 'PCWIN64' % Windows
        ext = '.sh'; % In fact .sh because we launch libRadtran through Cygwin
    case 'GLNXA64' % Linux
        ext = '.sh';
    case 'MACI64' % MacOS
        ext = '.sh';
end

[rtmpath,rtmname,~] = fileparts(alg.RTMfilepath);

% Run file to later extract solar irradiance. Only one file (divided into 
% the different spectral bands) for the entire LUT:
ind = strfind(alg.GenConf.filename,filesep);
path = alg.GenConf.filename(1:ind(end)-1);
dr = dir([alg.GenConf.filename,'_irr_*.inp']);
fid = fopen([alg.GenConf.filename,'_irr',ext],'w');
switch comp
    case 'PCWIN64' % Windows
    	fprintf(fid,'%-100s\n',['cd "',rtmpath,'"']);
    case {'GLNXA64','MACI64'} % Linux or MacOS
    	fprintf(fid,'%-100s\n',['cd ',rtmpath]);
end
for j=1:numel(dr)
    inp = [path,filesep,dr(j).name];
    out = strrep(inp,'.inp','.out');
    switch comp
    	case 'PCWIN64' % Windows
        	auxcmdline = ['./',rtmname,' <"',inp,'" >"',out,'"'];
            auxcmdline = strrep(auxcmdline,'\','/');
            fprintf(fid,'%-300s\n',auxcmdline);
        case {'GLNXA64','MACI64'} % Linux or MacOS
        	fprintf(fid,'%-300s\n',['./',rtmname,' <',inp,' >',out,'']);
    end
end
fclose(fid);
switch comp
    case 'PCWIN64' % Windows
    	callLibradtran = ['c:/cygwin64/bin/bash.exe --login -c "''',...
                          alg.GenConf.filename,'_irr',ext,'''"'];
        callLibradtran = strrep(callLibradtran,'\','/');
        evalin('base',['!',callLibradtran,' &'])
    case {'GLNXA64','MACI64'} % Linux or MacOS
    	evalin('base',['!',alg.GenConf.filename,'_irr',ext,' &'])
end


Nparallel = str2num(alg.GenConf.parallel);
% Loop for the number of parallel executions of the RTM:
for i = 1:Nparallel
    % Create script file and run libRadtran
    path = [alg.GenConf.filename,'_',num2str(i)];
    fid = fopen([path,ext],'w');
    switch comp
        case 'PCWIN64' % Windows
            fprintf(fid,'%-100s\n',['cd "',rtmpath,'"']);
        case {'GLNXA64','MACI64'} % Linux or MacOS
            fprintf(fid,'%-100s\n',['cd ',rtmpath]);
    end
    dr = dir([path,filesep,'*.inp']);
    for j=1:numel(dr)
            inp = [path,filesep,dr(j).name];
            out = strrep(inp,'.inp','.out');
            switch comp
                case 'PCWIN64' % Windows
                    auxcmdline = ['./',rtmname,' <"',inp,'" >"',out,'"'];
                    auxcmdline = strrep(auxcmdline,'\','/');
                    fprintf(fid,'%-300s\n',auxcmdline);
                case {'GLNXA64','MACI64'} % Linux or MacOS
                    fprintf(fid,'%-300s\n',['./',rtmname,' <',inp,' >',out,'']);
            end
    end
    fclose(fid);
end
if isempty(parspmb)
    switch comp
        case 'PCWIN64' % Windows
            for i = 1:Nparallel
                % This next line calls the shell script outside of Matlab
                % In Windows, libRadtran is called from cygwin
                % REVIEW so that ALG knows automatically where cygwin is
                % installed. Now it's hard
                callLibradtran = ['c:/cygwin64/bin/bash.exe --login -c "''',...
                                  alg.GenConf.filename,'_',num2str(i),ext,'''"'];
                callLibradtran = strrep(callLibradtran,'\','/');
                evalin('base',['!',callLibradtran,' &'])
            end
        case {'GLNXA64','MACI64'} % Linux or MacOS
            for i = 1:Nparallel
                % This next line calls the shell script outside of Matlab
                evalin('base',['!',alg.GenConf.filename,'_',num2str(i),ext,' &'])
            end
    end
elseif strcmp(parspmb,'spmd')
	if Nparallel==1
        flag = true; n0 = 0;
        while flag
            switch comp
                case 'PCWIN64' % Windows
                    callLibradtran = ['c:/cygwin64/bin/bash.exe --login -c "''',...
                                  alg.GenConf.filename,'_1',ext,'''"'];
                    callLibradtran = strrep(callLibradtran,'\','/');
                    evalin('base',['!',callLibradtran,' &'])
                case {'GLNXA64','MACI64'} % Linux or MacOS
                    % This next line calls the shell script from Matlab (i.e. 
                    % Matlab is busy until the libRadtran finishes running)
                    evalin('base',['!',alg.GenConf.filename,'_1',ext])
            end
        end
    else
    	parpool(Nparallel)
        spmd
            i=labindex;
            flag = true; n0 = 0;
            while flag
                switch comp
                    case 'PCWIN64' % Windows
                        callLibradtran = ['c:/cygwin64/bin/bash.exe --login -c "''',...
                                      alg.GenConf.filename,'_',num2str(i),ext,'''"'];
                        callLibradtran = strrep(callLibradtran,'\','/');
                        evalin('base',['!',callLibradtran,' &'])
                    case {'GLNXA64','MACI64'} % Linux or MacOS
                        % This next line calls the shell script from Matlab (i.e. 
                        % Matlab is busy until libRadtran finishes running)
                        evalin('base',['!',alg.GenConf.filename,'_',num2str(i),ext])
                end
            end
        end
    end
end

