function [] = runRTM(alg,parspmb)
cellfind = @(string)(@(cell_contents)(strcmp(string,cell_contents)));

% Once the input files are generated, the atmospheric RTM is run for each
% combination of key input atmospheric parameters. This step considers the
% possibility of multithreading
       
comp = computer;
switch comp
    case 'PCWIN64' % Windows
        ext = '.bat';
    case 'GLNXA64' % Linux
        ext = '.sh';
    case 'MACI64' % MacOS
        ext = '.sh';
end
       
Nparallel = str2num(alg.GenConf.parallel);
Ncomb = alg.numberCombinations();
if Ncomb<Nparallel, Nparallel = Ncomb; end

ratio = Ncomb/Nparallel;

%Loop for the number of parallel executions of the RTM:
for i = 1:Nparallel
	% Create script file and run 6SV
    fid = fopen([alg.GenConf.filename,'_',num2str(i),ext],'w');
    fprintf(fid,'%-100s\n',['cd ',alg.GenConf.filename,'_',num2str(i)]);
    if i==Nparallel, extra = (ratio-floor(ratio))*Nparallel; else extra=0; end
    % Loop for each combination (at each block of parallel execution):
    for j=(i-1)*floor(ratio)+1:i*floor(ratio)+extra
        inputname = ['comb',num2str(j)];
        aux = dir([alg.GenConf.filename,'_',num2str(i),'\',inputname,'_*.in']);
        for k=1:numel(aux) % Loop for each spectral band
        	inputname  = [alg.GenConf.filename,'_',num2str(i),'\',aux(k).name];
            outputname = strrep(inputname,'.in','.out');
            fprintf(fid,'%-100s\n',['"',alg.RTMfilepath,'" ','< "',inputname,'"> "',outputname,'"']);
        end
    end
    fclose(fid);
end

if isempty(parspmb)
	for i = 1:Nparallel
        evalin('base',['!',alg.GenConf.filename,'_',num2str(i),ext,' &'])
    end
elseif strcmp(parspmb,'spmd')
    if Nparallel==1
        evalin('base',['!',alg.GenConf.filename,'_1',ext])
    else
    	parpool(Nparallel)
		spmd
        	i=labindex;
            evalin('base',['!',alg.GenConf.filename,'_',num2str(i),ext])
        end
    end
end
