classdef sixSV<ALG
    %MODTRAN5 Summary of this class goes here
    %   Detailed explanation goes here
    
    properties
        
    end
    
    methods
        function this=sixSV(LUTconffile,RTMconffile)
            this = this@ALG(LUTconffile,RTMconffile);
        end
    end
    
    methods % Functions for preparing input files        
        % Write collection of 6SV input files
        function writeInputs(this,h)
            % Number of parallel RTM executions
            Nparallel = str2num(this.GenConf.parallel);
            % Total number of LUT nodes
            Ncomb = this.numberCombinations();
            if Ncomb<Nparallel, Nparallel = Ncomb; end
            ratio = Ncomb/Nparallel;

            % Loop for the number of parallel executions of the RTM:
            for i = 1:Nparallel
                % Make sub-directories where to store 6SV data:
                this.makesubdir(i)

                % Create INPUT files:
                if i==Nparallel, extra = (ratio-floor(ratio))*Nparallel;
                else,            extra = 0;
                end

                % Loop for each combination (at each block of parallel execution):
                for j=(i-1)*floor(ratio)+1:i*floor(ratio)+extra
                    waitbar((j-(i-1)*floor(ratio)+1)/floor(ratio),h,['Writing ',this.GenConf.RTMname,' input files'])
                    inputname = ['comb',num2str(j)];                        
                    if isempty(this.LUTheader) 
                        inputs = this.inputs0;
                    else
                    	inputs  = [this.inputs0;num2cell(this.LUTheader(:,j))];
                    end
                    if isstruct(this.AER) % Checks if OPAC or user-defined aerosol are used in LUT
                    	% Convert input Aerosol model into OPAC or user-defined
                        % aerosol parameters:
                        if inputs{this.AER.ind}<0 || inputs{this.AER.ind}>10
                        	% Aerosol model for current simulation is OPAC or user-defined
                            inputs{this.AER.ind} = this.AER.opticalProp(this.AER.aerIDs==inputs{this.AER.ind});
                        end
                    end
                    % 6SV has only one operation mode to compute outputs:
                    this.writeRTMinput([this.GenConf.filename,'_',num2str(i),filesep,inputname,'.in'],0.5,this.varnames,inputs,this.SpeConf);
                end
            end
            close(h)
        end
        
        % Make sub-folders where to store 6SV files
        function makesubdir(this,i)
            % Make sub-directories where to store 6SV data:
            mkdir([this.GenConf.filename,'_',num2str(i)]) % 6SV I/O sub-directory
        end
        
        % Run 6SV RTM
        runRTM(this,parspmb)
    end
    
    methods % Functions to create LUT file
        % Create LUT file by reading 6SV output files
        function createLUTfile(this,iter)
            % Read LUT header
            hdr       = readLUThdr([this.GenConf.filename,'.h5']);
            this.LUTheader = hdr.LUTheader;
             % Number of parallel RTM executions
            Nparallel = str2num(this.GenConf.parallel);
            % Total number of LUT nodes
            Ncomb = this.numberCombinations();

            h = waitbar(0,'','Name','Populating LUT file. Please wait...');
            color = [0.5 0 0]; set(findobj(h,'type','patch'),'facecolor',color);

            if iter>0
                info  = h5info([this.GenConf.filename,'.h5'], '/LUTdata');
                n     = info.Dataspace.Size(2);
                Ncomb = Ncomb - n;
            else
                n     = 0;
            end
            % Total number of LUT nodes
            if Ncomb<Nparallel, Nparallel = Ncomb; end
            ratio = Ncomb/Nparallel;
            
            % Loop for the number of parallel executions of the RTM:
            for i=1:Nparallel
                if i==Nparallel, extra = (ratio-floor(ratio))*Nparallel; else extra=0; end
                % Loop for each combination (at each block of parallel execution):
                for j=(i-1)*floor(ratio)+1:i*floor(ratio)+extra
                    waitbar((j-(i-1)*floor(ratio)+1)/floor(ratio),h,'Populating LUT file. Please wait...')
                    outputname = ['comb',num2str(j)];
                    aux = dir([this.GenConf.filename,'_',num2str(i),filesep,outputname,'_*.out']);
                    lambda = [];     Lp0  = lambda; Tgas = lambda;
                    Etot   = lambda; Ttot = lambda; S = lambda; I0 = lambda;
                    for k=1:numel(aux) % Loop for each spectral band
                        outputname = [this.GenConf.filename,'_',num2str(i),filesep,aux(k).name];
                        [auxlambda,auxLp0,auxTgas,auxEtot,auxTtot,auxS,auxI0] = this.readRTMoutput(outputname);
                        lambda = [lambda;auxlambda];
                        Lp0    = [Lp0;auxLp0];
                        Tgas   = [Tgas;auxTgas];
                        Etot   = [Etot;auxEtot];
                        Ttot   = [Ttot;auxTtot];
                        S      = [S;auxS];
                        I0     = [I0;auxI0];
                    end
                    % Save data into LUT hdf5 file:
                    if i==1 && j==1 && (isempty(iter) || iter==0)
                        if isempty(iter)
                            % LUT file is created without possibility of 
                            % being expanded ==> no chunking
                            h5create([this.GenConf.filename,'.h5'],'/LUTdata',[5*numel(lambda) Ncomb]);
                        elseif iter==0
                            % LUT file will be expanded in next iteration 
                            % ==> define chunking
                            h5create([this.GenConf.filename,'.h5'],'/LUTdata',[5*numel(lambda) Inf],'ChunkSize',[5*numel(lambda) Ncomb]);
                        end
                        outvarnames = {'Path Radiance (Lp0) [mW/m2/sr/nm]',...
                                       'Total gas transmittance (Tgas) [-]',...
                                       'Total at-surface irradiance due to scattering (Etot) [mW/m2/nm]',...  
                                       'Total upwards transmittance due to scattering (Ttot) [-]',...
                                       'Spherical albedo (S) [-]'};
                        this.updateLUThdr(lambda,I0,outvarnames,[])
                    end    
                    start = [1,j+n]; count = [5*numel(lambda) 1];
                    h5write([this.GenConf.filename,'.h5'], '/LUTdata',[Lp0;Tgas;Etot;Ttot;S],start,count);
                end
            end
            close(h)
        end
    end
    
    methods(Static)
        % Write 6SV input file
        writeRTMinput(file,rho,varnames,inputval,SpeConf);
        
        % Read 6SV output file
        [wvl,Lp0,Tgas,Etot,Ttot,S,I0] = readRTMoutput(file); 
    end
end

