%      BLOCK DATA MLATMB
%______________________________________________________________________|
%                                                                      |
%     Copyright 2009 Spectral Sciences, Inc.                           |
%                                                                      |
%     Neither Spectral Sciences, Inc. nor its employees makes any      |
%     warranty, express or implied, regarding the uses, accuracy,      |
%     or completeness of this software.                                |
%______________________________________________________________________|

%     THIS SUBROUTINE INITIALIZES THE 6 BUILT-IN ATMOSPHERIC PROFILES
%     (FROM 'OPTICAL PROPERTIES OF THE ATMOSPHERE, THIRD EDITION'
%     AFCRL-72-0497 (AD 753 075), 'U.S. STANDARD ATMOSPHERE 1976' AND
%     'SUPPLEMENTS 1966'), PLUS COLLECTED CONSTITUENT PROFILES (REF)
%     AND SETS OTHER CONSTANTS RELATED TO THE ATMOSPHERIC PROFILES

%     COMMONS:

%     ];MLATM];
%       ALT      MODEL ATMOSPHERE ABOVE SEA LEVEL ALTITUDE LEVELS [KM].
%       PMLOG    NATURAL LOG OF PRESSURE PER MBAR FOR 6 MODEL PROFILES.
%       TMATM    6 MODEL ATMOSPHERE TEMPERATURE PROFILES [K].
%       AMOL     6 MODEL ATM DENSITY PROFILES, MOLECULES 1 TO 8 [ppmV].
%       DOUBLE PRECISION ALT
%       REAL PMLOG,TMATM,AMOL
%       COMMON];MLATM];ALT(NLEVEL),PMLOG(NLEVEL,6),TMATM(NLEVEL,6),         
%        AMOL(NLEVEL,6,8)
% 
%       REAL TRAC
%       COMMON];TRACE];TRAC(NLEVEL,21)
%       SAVE ];MLATM];,];TRACE];

fileh5 = 'E:\Mis Documentos D\Modtran LUTGen\Software\LUTGen\Others/atmprofiles.h5';
fidh5 = H5F.create(fileh5);
h5writeatt(fileh5,'/','created','23-10-2018')
h5writeatt(fileh5,'/','description','Vertical profiles of atmospheric gases. Source: MODTRAN6 (mlatmb.m)')

h5create(fileh5,'/latitude',[1,6])
h5write(fileh5,'/latitude',[15 45 45 62 62 40])
h5writeatt(fileh5,'/latitude','unit','deg');
h5create(fileh5,'/doy',[1,6])
h5write(fileh5,'/doy',[0 182 1 182 1 0])
h5writeatt(fileh5,'/doy','unit','day');


% Altitude of each layer: ZM (KM)
ZM = [0.00,     1.00,     2.00,     3.00,     4.00,...
       5.00,     6.00,     7.00,     8.00,     9.00,...
       10.00,    11.00,    12.00,    13.00,    14.00,...
       15.00,    16.00,    17.00,    18.00,    19.00,...
       20.00,    21.00,    22.00,    23.00,    24.00,...
       25.00,    27.5D0,    30.00,    32.5D0,    35.00,...
       37.50,    40.00,    42.5D0,    45.00,    47.5D0,...
       50.00,    55.00,    60.00,    65.00,    70.00,...
       75.00,    80.00,    85.00,    90.00,    95.00,...
       100.00,   105.00,   110.00,   115.00,   120.00];
h5create(fileh5,'/ZM',[1,numel(ZM)])
h5write(fileh5,'/ZM',ZM)
h5writeatt(fileh5,'/ZM','unit','km');


% h5writeatt(fileh5,['/',name,'/',fn{i}],'unit','ppmv');
%     DATA LOG(PRESSURE];MBAR) [I.E. PRESSURE = EXP(PMLOG) mbar]:
P(1,:) = [6.92067,   6.80683,   6.69084,   6.57228,   6.45047,...
          6.32615,   6.19848,   6.06843,   5.93489,   5.79606,...
          5.65599,   5.50939,   5.36129,   5.20401,   5.04986,...
          4.88280,   4.70953,   4.54010,   4.36818,   4.19870,...
          4.03424,   3.87120,   3.71113,   3.55535,   3.40120,...
          3.24649,   2.86960,   2.50144,   2.14242,   1.79176,...
          1.44927,   1.11514,   0.78846,   0.46373,   0.14842,...
         -0.15782,  -0.78526,  -1.43129,  -2.11196,  -2.84731,...
         -3.64966,  -4.50986,  -5.42615,  -6.36543,  -7.28172,...
         -8.14908,  -8.94798,  -9.64575, -10.23199, -10.70200];
P(2,:) = [6.92067,   6.80461,   6.68711,   6.56526,   6.44254,...
          6.31716,   6.18826,   6.05444,   5.91889,   5.78074,...
          5.63835,   5.49306,   5.34233,   5.18739,   5.03044,...
          4.86753,   4.70953,   4.55388,   4.39692,   4.24133,...
          4.08598,   3.93183,   3.77735,   3.62700,   3.47197,...
          3.32143,   2.94812,   2.58022,   2.23001,   1.87487,...
          1.53471,   1.20297,   0.87963,   0.56531,   0.25464,...
         -0.05024,  -0.66359,  -1.30195,  -1.97328,  -2.70306,...
         -3.50656,  -4.42285,  -5.40813,  -6.41306,  -7.37776,...
         -8.26255,  -9.05334,  -9.70300, -10.24316, -10.69315];
P(3,:) = [6.92560,   6.79939,   6.67165,   6.54218,   6.41034,...
          6.27533,   6.13708,   5.99546,   5.85019,   5.70145,...
          5.54830,   5.39317,   5.23751,   5.08203,   4.92580,...
          4.76899,   4.61215,   4.45551,   4.29865,   4.13996,...
          3.98341,   3.82428,   3.66612,   3.50856,   3.35341,...
          3.19458,   2.80093,   2.40695,   2.02287,   1.64481,...
          1.28093,   0.92822,   0.58779,   0.25464,  -0.06188,...
         -0.38126,  -1.01611,  -1.67131,  -2.35388,  -3.05761,...
         -3.80766,  -4.57561,  -5.39043,  -6.22466,  -7.03900,...
         -7.80572,  -8.51719,  -9.15491,  -9.72450, -10.23199];
P(4,:) = [6.91771,   6.79794,   6.67570,   6.55108,   6.42325,...
          6.29342,   6.16121,   6.02345,   5.88332,   5.73915,...
          5.58987,   5.43808,   5.28675,   5.13580,   4.98361,...
          4.83628,   4.68213,   4.53045,   4.37952,   4.22829,...
          4.07754,   3.92593,   3.77506,   3.62434,   3.47445,...
          3.32504,   2.95647,   2.59525,   2.24071,   1.88858,...
          1.55181,   1.22378,   0.90826,   0.59884,   0.29267,...
         -0.01309,  -0.62176,  -1.24479,  -1.91732,  -2.64508,...
         -3.44202,  -4.38203,  -5.40146,  -6.43152,  -7.40863,...
         -8.30208,  -9.08812,  -9.72117, -10.24880, -10.69756];
P(5,:) = [6.92067,   6.78875,   6.65608,   6.52180,   6.38553,...
          6.24572,   6.10189,   5.95402,   5.80151,   5.64509,...
          5.48811,   5.33127,   5.17389,   5.01728,   4.86059,...
          4.70320,   4.54659,   4.38925,   4.23149,   4.07329,...
          3.91482,   3.75584,   3.59649,   3.43689,   3.27677,...
          3.11618,   2.71668,   2.32239,   1.93297,   1.54778,...
          1.17248,   0.80781,   0.45108,   0.10706,  -0.23572,...
         -0.55879,  -1.20731,  -1.86433,  -2.53831,  -3.21888,...
         -3.91202,  -4.63976,  -5.40368,  -6.20367,  -7.00537,...
         -7.76814,  -8.48279,  -9.13338,  -9.72117, -10.23477];
P(6,:) = [6.92092,   6.80102,   6.67835,   6.55281,   6.42422,...
          6.29246,   6.15734,   6.01871,   5.87636,   5.73010,...
          5.57969,   5.42491,   5.26781,   5.11072,   4.95371,...
          4.79670,   4.63976,   4.48297,   4.32614,   4.16936,...
          4.01265,   3.85628,   3.70068,   3.54582,   3.39172,...
          3.23836,   2.85814,   2.48240,   2.11115,   1.74849,...
          1.39659,   1.05480,   0.72256,   0.39945,   0.08489,...
         -0.22591,  -0.85508,  -1.51604,  -2.21375,  -2.95250,...
         -3.73467,  -4.55410,  -5.41332,  -6.30022,  -7.18264,...
         -8.04685,  -8.84036,  -9.55224, -10.12423, -10.58147];
P = exp(P);
h5create(fileh5,'/P',[6,size(P,2)])
h5write(fileh5,'/P',P)
h5writeatt(fileh5,'/P','unit','mbar');

%     DATA TEMPERATURE [K];
T(1,:) = [299.70,    293.70,    287.70,    283.70,    277.00,...
         270.30,    263.60,    257.00,    250.30,    243.60,...
         237.00,    230.10,    223.60,    217.00,    210.30,...
         203.70,    197.00,    194.80,    198.80,    202.70,...
         206.70,    210.70,    214.60,    217.00,    219.20,...
         221.40,    227.00,    232.30,    237.70,    243.10,...
         248.50,    254.00,    259.40,    264.80,    269.60,...
         270.20,    263.40,    253.10,    236.00,    218.90,...
         201.80,    184.80,    177.10,    177.00,    184.30,...
         190.70,    212.00,    241.60,    299.70,    380.00];
T(2,:) = [294.20,    289.70,    285.20,    279.20,    273.20,...
         267.20,    261.20,    254.70,    248.20,    241.70,...
         235.30,    228.80,    222.30,    215.80,    215.70,...
         215.70,    215.70,    215.70,    216.80,    217.90,...
         219.20,    220.40,    221.60,    222.80,    223.90,...
         225.10,    228.45,    233.70,    239.00,    245.20,...
         251.30,    257.50,    263.70,    269.90,    275.20,...
         275.70,    269.30,    257.10,    240.10,    218.10,...
         196.10,    174.10,    165.10,    165.00,    178.30,...
         190.50,    222.20,    262.40,    316.80,    380.00];
T(3,:) = [272.20,    268.70,    265.20,    261.70,    255.70,...
         249.70,    243.70,    237.70,    231.70,    225.70,...
         219.70,    219.20,    218.70,    218.20,    217.70,...
         217.20,    216.70,    216.20,    215.70,    215.20,...
         215.20,    215.20,    215.20,    215.20,    215.20,...
         215.20,    215.50,    217.40,    220.40,    227.90,...
         235.50,    243.20,    250.80,    258.50,    265.10,...
         265.70,    260.60,    250.80,    240.90,    230.70,...
         220.40,    210.10,    199.80,    199.50,    208.30,...
         218.60,    237.10,    259.50,    293.00,    333.00];
T(4,:) = [287.20,    281.70,    276.30,    270.90,    265.50,...
         260.10,    253.10,    246.10,    239.20,    232.20,...
         225.20,    225.20,    225.20,    225.20,    225.20,...
         225.20,    225.20,    225.20,    225.20,    225.20,...
         225.20,    225.20,    225.20,    225.20,    226.60,...
         228.10,    231.00,    235.10,    240.00,    247.20,...
         254.60,    262.10,    269.50,    273.60,    276.20,...
         277.20,    274.00,    262.70,    239.70,    216.60,...
         193.60,    170.60,    161.70,    161.60,    176.80,...
         190.40,    226.00,    270.10,    322.70,    380.00];
T(5,:) = [257.20,    259.10,    255.90,    252.70,    247.70,...
         240.90,    234.10,    227.30,    220.60,    217.20,...
         217.20,    217.20,    217.20,    217.20,    217.20,...
         217.20,    216.60,    216.00,    215.40,    214.80,...
         214.20,    213.60,    213.00,    212.40,    211.80,...
         211.20,    213.60,    216.00,    218.50,    222.30,...
         228.50,    234.70,    240.80,    247.00,    253.20,...
         259.30,    259.10,    250.90,    248.40,    245.40,...
         234.70,    223.90,    213.10,    202.30,    211.00,...
         218.50,    234.00,    252.60,    288.50,    333.00];
T(6,:) = [288.150,   281.651,   275.154,   268.659,   262.166,...
        255.676,   249.187,   242.700,   236.215,   229.733,...
        223.252,   216.774,   216.650,   216.650,   216.650,...
        216.650,   216.650,   216.650,   216.650,   216.650,...
        216.650,   217.581,   218.574,   219.567,   220.560,...
        221.552,   224.032,   226.509,   229.587,   236.513,...
        243.434,   250.350,   257.260,   264.164,   270.650,...
        270.650,   260.771,   247.021,   233.292,   219.585,...
        208.399,   198.639,   188.893,   186.87 ,   188.42 ,...
        195.08 ,   208.84 ,   240.00 ,   300.00 ,   360.00 ];
h5create(fileh5,'/T',[6,size(T,2)])
h5write(fileh5,'/T',T)
h5writeatt(fileh5,'/T','unit','K');

%     DATA  H2O      ];
H2O(1,:) = [2.593E+04, 1.949E+04, 1.534E+04, 8.600E+03, 4.441E+03,...
            3.346E+03, 2.101E+03, 1.289E+03, 7.637E+02, 4.098E+02,...
            1.912E+02, 7.306E+01, 2.905E+01, 9.900E+00, 6.220E+00,...
            4.000E+00, 3.000E+00, 2.900E+00, 2.750E+00, 2.600E+00,...
            2.600E+00, 2.650E+00, 2.800E+00, 2.900E+00, 3.200E+00,...
            3.250E+00, 3.600E+00, 4.000E+00, 4.300E+00, 4.600E+00,...
            4.900E+00, 5.200E+00, 5.500E+00, 5.700E+00, 5.900E+00,...
            6.000E+00, 6.000E+00, 6.000E+00, 5.400E+00, 4.500E+00,...
            3.300E+00, 2.100E+00, 1.300E+00, 8.500E-01, 5.400E-01,...
            4.000E-01, 3.400E-01, 2.800E-01, 2.400E-01, 2.000E-01];
      H2O(2,:) = [...                                   
      1.876E+04, 1.378E+04, 9.680E+03, 5.984E+03, 3.813E+03,...
      2.225E+03, 1.510E+03, 1.020E+03, 6.464E+02, 4.129E+02,...
      2.472E+02, 9.556E+01, 2.944E+01, 8.000E+00, 5.000E+00,...
      3.400E+00, 3.300E+00, 3.200E+00, 3.150E+00, 3.200E+00,...
      3.300E+00, 3.450E+00, 3.600E+00, 3.850E+00, 4.000E+00,...
      4.200E+00, 4.450E+00, 4.700E+00, 4.850E+00, 4.950E+00,...
      5.000E+00, 5.100E+00, 5.300E+00, 5.450E+00, 5.500E+00,...
      5.500E+00, 5.350E+00, 5.000E+00, 4.400E+00, 3.700E+00,...
      2.950E+00, 2.100E+00, 1.330E+00, 8.500E-01, 5.400E-01,...
      4.000E-01, 3.400E-01, 2.800E-01, 2.400E-01, 2.000E-01];
      H2O(3,:) = [...                                   
      4.316E+03, 3.454E+03, 2.788E+03, 2.088E+03, 1.280E+03,...
      8.241E+02, 5.103E+02, 2.321E+02, 1.077E+02, 5.566E+01,...
      2.960E+01, 1.000E+01, 6.000E+00, 5.000E+00, 4.800E+00,...
      4.700E+00, 4.600E+00, 4.500E+00, 4.500E+00, 4.500E+00,...
      4.500E+00, 4.500E+00, 4.530E+00, 4.550E+00, 4.600E+00,...
      4.650E+00, 4.700E+00, 4.750E+00, 4.800E+00, 4.850E+00,...
      4.900E+00, 4.950E+00, 5.000E+00, 5.000E+00, 5.000E+00,...
      4.950E+00, 4.850E+00, 4.500E+00, 4.000E+00, 3.300E+00,...
      2.700E+00, 2.000E+00, 1.330E+00, 8.500E-01, 5.400E-01,...
      4.000E-01, 3.400E-01, 2.800E-01, 2.400E-01, 2.000E-01];
      H2O(4,:) = [...                                   
      1.194E+04, 8.701E+03, 6.750E+03, 4.820E+03, 3.380E+03,...
      2.218E+03, 1.330E+03, 7.971E+02, 3.996E+02, 1.300E+02,...
      4.240E+01, 1.330E+01, 6.000E+00, 4.450E+00, 4.000E+00,...
      4.000E+00, 4.000E+00, 4.050E+00, 4.300E+00, 4.500E+00,...
      4.600E+00, 4.700E+00, 4.800E+00, 4.830E+00, 4.850E+00,...
      4.900E+00, 4.950E+00, 5.000E+00, 5.000E+00, 5.000E+00,...
      5.000E+00, 5.000E+00, 5.000E+00, 5.000E+00, 5.000E+00,...
      4.950E+00, 4.850E+00, 4.500E+00, 4.000E+00, 3.300E+00,...
      2.700E+00, 2.000E+00, 1.330E+00, 8.500E-01, 5.400E-01,...
      4.000E-01, 3.400E-01, 2.800E-01, 2.400E-01, 2.000E-01];
      H2O(5,:) = [...                                   
      1.405E+03, 1.615E+03, 1.427E+03, 1.166E+03, 7.898E+02,...
      4.309E+02, 2.369E+02, 1.470E+02, 3.384E+01, 2.976E+01,...
      2.000E+01, 1.000E+01, 6.000E+00, 4.450E+00, 4.500E+00,...
      4.550E+00, 4.600E+00, 4.650E+00, 4.700E+00, 4.750E+00,...
      4.800E+00, 4.850E+00, 4.900E+00, 4.950E+00, 5.000E+00,...
      5.000E+00, 5.000E+00, 5.000E+00, 5.000E+00, 5.000E+00,...
      5.000E+00, 5.000E+00, 5.000E+00, 5.000E+00, 5.000E+00,...
      4.950E+00, 4.850E+00, 4.500E+00, 4.000E+00, 3.300E+00,...
      2.700E+00, 2.000E+00, 1.330E+00, 8.500E-01, 5.400E-01,...
      4.000E-01, 3.400E-01, 2.800E-01, 2.400E-01, 2.000E-01];
      H2O(6,:) = [...                                   
      7.745E+03, 6.071E+03, 4.631E+03, 3.182E+03, 2.158E+03,...
      1.397E+03, 9.254E+02, 5.720E+02, 3.667E+02, 1.583E+02,...
      6.996E+01, 3.613E+01, 1.906E+01, 1.085E+01, 5.927E+00,...
      5.000E+00, 3.950E+00, 3.850E+00, 3.825E+00, 3.850E+00,...
      3.900E+00, 3.975E+00, 4.065E+00, 4.200E+00, 4.300E+00,...
      4.425E+00, 4.575E+00, 4.725E+00, 4.825E+00, 4.900E+00,...
      4.950E+00, 5.025E+00, 5.150E+00, 5.225E+00, 5.250E+00,...
      5.225E+00, 5.100E+00, 4.750E+00, 4.200E+00, 3.500E+00,...
      2.825E+00, 2.050E+00, 1.330E+00, 8.500E-01, 5.400E-01,...
      4.000E-01, 3.400E-01, 2.800E-01, 2.400E-01, 2.000E-01];
h5create(fileh5,'/H2O',[6,size(H2O,2)])
h5write(fileh5,'/H2O',H2O)
h5writeatt(fileh5,'/H2O','unit','ppmv');

%     DATA CO2       ];
      CO2(1,:) = [...                                   
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.280E+02, 3.200E+02, 3.100E+02, 2.700E+02,...
      1.950E+02, 1.100E+02, 6.000E+01, 4.000E+01, 3.500E+01];
      CO2(2,:) = [...                                   
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.280E+02, 3.200E+02, 3.100E+02, 2.700E+02,...
      1.950E+02, 1.100E+02, 6.000E+01, 4.000E+01, 3.500E+01];
      CO2(3,:) = [...                                   
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.280E+02, 3.200E+02, 3.100E+02, 2.700E+02,...
      1.950E+02, 1.100E+02, 6.000E+01, 4.000E+01, 3.500E+01];
      CO2(4,:) = [...                                   
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.280E+02, 3.200E+02, 3.100E+02, 2.700E+02,...
      1.950E+02, 1.100E+02, 6.000E+01, 4.000E+01, 3.500E+01];
      CO2(5,:) = [...                                   
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.280E+02, 3.200E+02, 3.100E+02, 2.700E+02,...
      1.950E+02, 1.100E+02, 6.000E+01, 4.000E+01, 3.500E+01];
      CO2(6,:) = [...                                   
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02, 3.300E+02,...
      3.300E+02, 3.280E+02, 3.200E+02, 3.100E+02, 2.700E+02,...
      1.950E+02, 1.100E+02, 6.000E+01, 4.000E+01, 3.500E+01];
h5create(fileh5,'/CO2',[6,size(CO2,2)])
h5write(fileh5,'/CO2',CO2)
h5writeatt(fileh5,'/CO2','unit','ppmv');

%     DATA OZONE     ];
      O3(1,:) = [...                                   
      2.869E-02, 3.150E-02, 3.342E-02, 3.504E-02, 3.561E-02,...
      3.767E-02, 3.989E-02, 4.223E-02, 4.471E-02, 5.000E-02,...
      5.595E-02, 6.613E-02, 7.815E-02, 9.289E-02, 1.050E-01,...
      1.256E-01, 1.444E-01, 2.500E-01, 5.000E-01, 9.500E-01,...
      1.400E+00, 1.800E+00, 2.400E+00, 3.400E+00, 4.300E+00,...
      5.400E+00, 7.800E+00, 9.300E+00, 9.850E+00, 9.700E+00,...
      8.800E+00, 7.500E+00, 5.900E+00, 4.500E+00, 3.450E+00,...
      2.800E+00, 1.800E+00, 1.100E+00, 6.500E-01, 3.000E-01,...
      1.800E-01, 3.300E-01, 5.000E-01, 5.200E-01, 5.000E-01,...
      4.000E-01, 2.000E-01, 5.000E-02, 5.000E-03, 5.000E-04];
      O3(2,:) = [...                                   
      3.017E-02, 3.337E-02, 3.694E-02, 4.222E-02, 4.821E-02,...
      5.512E-02, 6.408E-02, 7.764E-02, 9.126E-02, 1.111E-01,...
      1.304E-01, 1.793E-01, 2.230E-01, 3.000E-01, 4.400E-01,...
      5.000E-01, 6.000E-01, 7.000E-01, 1.000E+00, 1.500E+00,...
      2.000E+00, 2.400E+00, 2.900E+00, 3.400E+00, 4.000E+00,...
      4.800E+00, 6.000E+00, 7.000E+00, 8.100E+00, 8.900E+00,...
      8.700E+00, 7.550E+00, 5.900E+00, 4.500E+00, 3.500E+00,...
      2.800E+00, 1.800E+00, 1.300E+00, 8.000E-01, 4.000E-01,...
      1.900E-01, 2.000E-01, 5.700E-01, 7.500E-01, 7.000E-01,...
      4.000E-01, 2.000E-01, 5.000E-02, 5.000E-03, 5.000E-04];
      O3(3,:) = [...                                   
      2.778E-02, 2.800E-02, 2.849E-02, 3.200E-02, 3.567E-02,...
      4.720E-02, 5.837E-02, 7.891E-02, 1.039E-01, 1.567E-01,...
      2.370E-01, 3.624E-01, 5.232E-01, 7.036E-01, 8.000E-01,...
      9.000E-01, 1.100E+00, 1.400E+00, 1.800E+00, 2.300E+00,...
      2.900E+00, 3.500E+00, 3.900E+00, 4.300E+00, 4.700E+00,...
      5.100E+00, 5.600E+00, 6.100E+00, 6.800E+00, 7.100E+00,...
      7.200E+00, 6.900E+00, 5.900E+00, 4.600E+00, 3.700E+00,...
      2.750E+00, 1.700E+00, 1.000E-00, 5.500E-01, 3.200E-01,...
      2.500E-01, 2.300E-01, 5.500E-01, 8.000E-01, 8.000E-01,...
      4.000E-01, 2.000E-01, 5.000E-02, 5.000E-03, 5.000E-04];
      O3(4,:) = [...                                   
      2.412E-02, 2.940E-02, 3.379E-02, 3.887E-02, 4.478E-02,...
      5.328E-02, 6.564E-02, 7.738E-02, 9.114E-02, 1.420E-01,...
      1.890E-01, 3.050E-01, 4.100E-01, 5.000E-01, 6.000E-01,...
      7.000E-01, 8.500E-01, 1.000E+00, 1.300E+00, 1.700E+00,...
      2.100E+00, 2.700E+00, 3.300E+00, 3.700E+00, 4.200E+00,...
      4.500E+00, 5.300E+00, 5.700E+00, 6.900E+00, 7.700E+00,...
      7.800E+00, 7.000E+00, 5.400E+00, 4.200E+00, 3.200E+00,...
      2.500E+00, 1.700E+00, 1.200E+00, 8.000E-01, 4.000E-01,...
      2.000E-01, 1.800E-01, 6.500E-01, 9.000E-01, 8.000E-01,...
      4.000E-01, 2.000E-01, 5.000E-02, 5.000E-03, 5.000E-04];
      O3(5,:) = [...                                   
      1.802E-02, 2.072E-02, 2.336E-02, 2.767E-02, 3.253E-02,...
      3.801E-02, 4.446E-02, 7.252E-02, 1.040E-01, 2.100E-01,...
      3.000E-01, 3.500E-01, 4.000E-01, 6.500E-01, 9.000E-01,...
      1.200E+00, 1.500E+00, 1.900E+00, 2.450E+00, 3.100E+00,...
      3.700E+00, 4.000E+00, 4.200E+00, 4.500E+00, 4.600E+00,...
      4.700E+00, 4.900E+00, 5.400E+00, 5.900E+00, 6.200E+00,...
      6.250E+00, 5.900E+00, 5.100E+00, 4.100E+00, 3.000E+00,...
      2.600E+00, 1.600E+00, 9.500E-01, 6.500E-01, 5.000E-01,...
      3.300E-01, 1.300E-01, 7.500E-01, 8.000E-01, 8.000E-01,...
      4.000E-01, 2.000E-01, 5.000E-02, 5.000E-03, 5.000E-04];
      O3(6,:) = [...                                   
      2.660E-02, 2.931E-02, 3.237E-02, 3.318E-02, 3.387E-02,...
      3.768E-02, 4.112E-02, 5.009E-02, 5.966E-02, 9.168E-02,...
      1.313E-01, 2.149E-01, 3.095E-01, 3.846E-01, 5.030E-01,...
      6.505E-01, 8.701E-01, 1.187E+00, 1.587E+00, 2.030E+00,...
      2.579E+00, 3.028E+00, 3.647E+00, 4.168E+00, 4.627E+00,...
      5.118E+00, 5.803E+00, 6.553E+00, 7.373E+00, 7.837E+00,...
      7.800E+00, 7.300E+00, 6.200E+00, 5.250E+00, 4.100E+00,...
      3.100E+00, 1.800E+00, 1.100E+00, 7.000E-01, 3.000E-01,...
      2.500E-01, 3.000E-01, 5.000E-01, 7.000E-01, 7.000E-01,...
      4.000E-01, 2.000E-01, 5.000E-02, 5.000E-03, 5.000E-04];
h5create(fileh5,'/O3',[6,size(O3,2)])
h5write(fileh5,'/O3',O3)
h5writeatt(fileh5,'/O3','unit','ppmv');

%     DATA  N2O      ];
      N2O(1,:) = [...                                   
      3.200E-01, 3.200E-01, 3.200E-01, 3.200E-01, 3.200E-01,...
      3.200E-01, 3.200E-01, 3.200E-01, 3.200E-01, 3.195E-01,...
      3.179E-01, 3.140E-01, 3.095E-01, 3.048E-01, 2.999E-01,...
      2.944E-01, 2.877E-01, 2.783E-01, 2.671E-01, 2.527E-01,...
      2.365E-01, 2.194E-01, 2.051E-01, 1.967E-01, 1.875E-01,...
      1.756E-01, 1.588E-01, 1.416E-01, 1.165E-01, 9.275E-02,...
      6.693E-02, 4.513E-02, 2.751E-02, 1.591E-02, 9.378E-03,...
      4.752E-03, 3.000E-03, 2.065E-03, 1.507E-03, 1.149E-03,...
      8.890E-04, 7.056E-04, 5.716E-04, 4.708E-04, 3.932E-04,...
      3.323E-04, 2.837E-04, 2.443E-04, 2.120E-04, 1.851E-04];
      N2O(2,:) = [...                                   
      3.200E-01, 3.200E-01, 3.200E-01, 3.200E-01, 3.200E-01,...
      3.200E-01, 3.200E-01, 3.200E-01, 3.195E-01, 3.163E-01,...
      3.096E-01, 2.989E-01, 2.936E-01, 2.860E-01, 2.800E-01,...
      2.724E-01, 2.611E-01, 2.421E-01, 2.174E-01, 1.843E-01,...
      1.607E-01, 1.323E-01, 1.146E-01, 1.035E-01, 9.622E-02,...
      8.958E-02, 8.006E-02, 6.698E-02, 4.958E-02, 3.695E-02,...
      2.519E-02, 1.736E-02, 1.158E-02, 7.665E-03, 5.321E-03,...
      3.215E-03, 2.030E-03, 1.397E-03, 1.020E-03, 7.772E-04,...
      6.257E-04, 5.166E-04, 4.352E-04, 3.727E-04, 3.237E-04,...
      2.844E-04, 2.524E-04, 2.260E-04, 2.039E-04, 1.851E-04];
      N2O(3,:) = [...                                   
      3.200E-01, 3.200E-01, 3.200E-01, 3.200E-01, 3.200E-01,...
      3.200E-01, 3.200E-01, 3.200E-01, 3.195E-01, 3.163E-01,...
      3.096E-01, 2.989E-01, 2.936E-01, 2.860E-01, 2.800E-01,...
      2.724E-01, 2.611E-01, 2.421E-01, 2.174E-01, 1.843E-01,...
      1.621E-01, 1.362E-01, 1.230E-01, 1.124E-01, 1.048E-01,...
      9.661E-02, 8.693E-02, 7.524E-02, 6.126E-02, 5.116E-02,...
      3.968E-02, 2.995E-02, 2.080E-02, 1.311E-02, 8.071E-03,...
      4.164E-03, 2.629E-03, 1.809E-03, 1.321E-03, 1.007E-03,...
      7.883E-04, 6.333E-04, 5.194E-04, 4.333E-04, 3.666E-04,...
      3.140E-04, 2.717E-04, 2.373E-04, 2.089E-04, 1.851E-04];
      N2O(4,:) = [...                                   
      3.100E-01, 3.100E-01, 3.100E-01, 3.100E-01, 3.079E-01,...
      3.024E-01, 2.906E-01, 2.822E-01, 2.759E-01, 2.703E-01,...
      2.651E-01, 2.600E-01, 2.549E-01, 2.494E-01, 2.433E-01,...
      2.355E-01, 2.282E-01, 2.179E-01, 2.035E-01, 1.817E-01,...
      1.567E-01, 1.350E-01, 1.218E-01, 1.102E-01, 9.893E-02,...
      8.775E-02, 7.327E-02, 5.941E-02, 4.154E-02, 3.032E-02,...
      1.949E-02, 1.274E-02, 9.001E-03, 6.286E-03, 4.558E-03,...
      2.795E-03, 1.765E-03, 1.214E-03, 8.866E-04, 6.756E-04,...
      5.538E-04, 4.649E-04, 3.979E-04, 3.459E-04, 3.047E-04,...
      2.713E-04, 2.439E-04, 2.210E-04, 2.017E-04, 1.851E-04];
      N2O(5,:) = [...                                   
      3.200E-01, 3.200E-01, 3.200E-01, 3.200E-01, 3.200E-01,...
      3.200E-01, 3.200E-01, 3.200E-01, 3.195E-01, 3.163E-01,...
      3.096E-01, 2.989E-01, 2.936E-01, 2.860E-01, 2.800E-01,...
      2.724E-01, 2.611E-01, 2.421E-01, 2.174E-01, 1.843E-01,...
      1.621E-01, 1.362E-01, 1.230E-01, 1.122E-01, 1.043E-01,...
      9.570E-02, 8.598E-02, 7.314E-02, 5.710E-02, 4.670E-02,...
      3.439E-02, 2.471E-02, 1.631E-02, 1.066E-02, 7.064E-03,...
      3.972E-03, 2.508E-03, 1.726E-03, 1.260E-03, 9.602E-04,...
      7.554E-04, 6.097E-04, 5.024E-04, 4.210E-04, 3.579E-04,...
      3.080E-04, 2.678E-04, 2.350E-04, 2.079E-04, 1.851E-04];
      N2O(6,:) = [...                                   
      3.200E-01, 3.200E-01, 3.200E-01, 3.200E-01, 3.200E-01,...
      3.200E-01, 3.200E-01, 3.200E-01, 3.200E-01, 3.195E-01,...
      3.179E-01, 3.140E-01, 3.095E-01, 3.048E-01, 2.999E-01,...
      2.944E-01, 2.877E-01, 2.783E-01, 2.671E-01, 2.527E-01,...
      2.365E-01, 2.194E-01, 2.051E-01, 1.967E-01, 1.875E-01,...
      1.756E-01, 1.588E-01, 1.416E-01, 1.165E-01, 9.275E-02,...
      6.693E-02, 4.513E-02, 2.751E-02, 1.591E-02, 9.378E-03,...
      4.752E-03, 3.000E-03, 2.065E-03, 1.507E-03, 1.149E-03,...
      8.890E-04, 7.056E-04, 5.716E-04, 4.708E-04, 3.932E-04,...
      3.323E-04, 2.837E-04, 2.443E-04, 2.120E-04, 1.851E-04];
h5create(fileh5,'/N2O',[6,size(N2O,2)])
h5write(fileh5,'/N2O',N2O)
h5writeatt(fileh5,'/N2O','unit','ppmv');

%     DATA CO        ];
      CO(1,:) = [...                                   
      1.500E-01, 1.450E-01, 1.399E-01, 1.349E-01, 1.312E-01,...
      1.303E-01, 1.288E-01, 1.247E-01, 1.185E-01, 1.094E-01,...
      9.962E-02, 8.964E-02, 7.814E-02, 6.374E-02, 5.025E-02,...
      3.941E-02, 3.069E-02, 2.489E-02, 1.966E-02, 1.549E-02,...
      1.331E-02, 1.232E-02, 1.232E-02, 1.307E-02, 1.400E-02,...
      1.521E-02, 1.722E-02, 1.995E-02, 2.266E-02, 2.487E-02,...
      2.738E-02, 3.098E-02, 3.510E-02, 3.987E-02, 4.482E-02,...
      5.092E-02, 5.985E-02, 6.960E-02, 9.188E-02, 1.938E-01,...
      5.688E-01, 1.549E+00, 3.849E+00, 6.590E+00, 1.044E+01,...
      1.705E+01, 2.471E+01, 3.358E+01, 4.148E+01, 5.000E+01];
      CO(2,:) = [...                                   
      1.500E-01, 1.450E-01, 1.399E-01, 1.349E-01, 1.312E-01,...
      1.303E-01, 1.288E-01, 1.247E-01, 1.185E-01, 1.094E-01,...
      9.962E-02, 8.964E-02, 7.814E-02, 6.374E-02, 5.025E-02,...
      3.941E-02, 3.069E-02, 2.489E-02, 1.966E-02, 1.549E-02,...
      1.331E-02, 1.232E-02, 1.232E-02, 1.307E-02, 1.400E-02,...
      1.521E-02, 1.722E-02, 1.995E-02, 2.266E-02, 2.487E-02,...
      2.716E-02, 2.962E-02, 3.138E-02, 3.307E-02, 3.487E-02,...
      3.645E-02, 3.923E-02, 4.673E-02, 6.404E-02, 1.177E-01,...
      2.935E-01, 6.815E-01, 1.465E+00, 2.849E+00, 5.166E+00,...
      1.008E+01, 1.865E+01, 2.863E+01, 3.890E+01, 5.000E+01];
      CO(3,:) = [...                                   
      1.500E-01, 1.450E-01, 1.399E-01, 1.349E-01, 1.312E-01,...
      1.303E-01, 1.288E-01, 1.247E-01, 1.185E-01, 1.094E-01,...
      9.962E-02, 8.964E-02, 7.814E-02, 6.374E-02, 5.025E-02,...
      3.941E-02, 3.069E-02, 2.489E-02, 1.966E-02, 1.549E-02,...
      1.331E-02, 1.232E-02, 1.232E-02, 1.307E-02, 1.400E-02,...
      1.498E-02, 1.598E-02, 1.710E-02, 1.850E-02, 1.997E-02,...
      2.147E-02, 2.331E-02, 2.622E-02, 3.057E-02, 3.803E-02,...
      6.245E-02, 1.480E-01, 2.926E-01, 5.586E-01, 1.078E+00,...
      1.897E+00, 2.960E+00, 4.526E+00, 6.862E+00, 1.054E+01,...
      1.709E+01, 2.473E+01, 3.359E+01, 4.149E+01, 5.000E+01];
      CO(4,:) = [...                                   
      1.500E-01, 1.450E-01, 1.399E-01, 1.349E-01, 1.312E-01,...
      1.303E-01, 1.288E-01, 1.247E-01, 1.185E-01, 1.094E-01,...
      9.962E-02, 8.964E-02, 7.814E-02, 6.374E-02, 5.025E-02,...
      3.941E-02, 3.069E-02, 2.489E-02, 1.966E-02, 1.549E-02,...
      1.331E-02, 1.232E-02, 1.232E-02, 1.307E-02, 1.400E-02,...
      1.510E-02, 1.649E-02, 1.808E-02, 1.997E-02, 2.183E-02,...
      2.343E-02, 2.496E-02, 2.647E-02, 2.809E-02, 2.999E-02,...
      3.220E-02, 3.650E-02, 4.589E-02, 6.375E-02, 1.176E-01,...
      3.033E-01, 7.894E-01, 1.823E+00, 3.402E+00, 5.916E+00,...
      1.043E+01, 1.881E+01, 2.869E+01, 3.892E+01, 5.000E+01];
      CO(5,:) = [...                                   
      1.500E-01, 1.450E-01, 1.399E-01, 1.349E-01, 1.312E-01,...
      1.303E-01, 1.288E-01, 1.247E-01, 1.185E-01, 1.094E-01,...
      9.962E-02, 8.964E-02, 7.814E-02, 6.374E-02, 5.025E-02,...
      3.941E-02, 3.069E-02, 2.489E-02, 1.966E-02, 1.549E-02,...
      1.331E-02, 1.232E-02, 1.232E-02, 1.307E-02, 1.400E-02,...
      1.521E-02, 1.722E-02, 2.037E-02, 2.486E-02, 3.168E-02,...
      4.429E-02, 6.472E-02, 1.041E-01, 1.507E-01, 2.163E-01,...
      3.141E-01, 4.842E-01, 7.147E-01, 1.067E+00, 1.516E+00,...
      2.166E+00, 3.060E+00, 4.564E+00, 6.877E+00, 1.055E+01,...
      1.710E+01, 2.473E+01, 3.359E+01, 4.149E+01, 5.000E+01];
      CO(6,:) = [...                                   
      1.500E-01, 1.450E-01, 1.399E-01, 1.349E-01, 1.312E-01,...
      1.303E-01, 1.288E-01, 1.247E-01, 1.185E-01, 1.094E-01,...
      9.962E-02, 8.964E-02, 7.814E-02, 6.374E-02, 5.025E-02,...
      3.941E-02, 3.069E-02, 2.489E-02, 1.966E-02, 1.549E-02,...
      1.331E-02, 1.232E-02, 1.232E-02, 1.307E-02, 1.400E-02,...
      1.498E-02, 1.598E-02, 1.710E-02, 1.850E-02, 2.009E-02,...
      2.220E-02, 2.497E-02, 2.824E-02, 3.241E-02, 3.717E-02,...
      4.597E-02, 6.639E-02, 1.073E-01, 1.862E-01, 3.059E-01,...
      6.375E-01, 1.497E+00, 3.239E+00, 5.843E+00, 1.013E+01,...
      1.692E+01, 2.467E+01, 3.356E+01, 4.148E+01, 5.000E+01];
h5create(fileh5,'/CO',[6,size(CO,2)])
h5write(fileh5,'/CO',CO)
h5writeatt(fileh5,'/CO','unit','ppmv');

%     DATA  CH4      ];
      CH4(1,:) = [...                                   
      1.700E+00, 1.700E+00, 1.700E+00, 1.700E+00, 1.700E+00,...
      1.700E+00, 1.700E+00, 1.699E+00, 1.697E+00, 1.693E+00,...
      1.685E+00, 1.675E+00, 1.662E+00, 1.645E+00, 1.626E+00,...
      1.605E+00, 1.582E+00, 1.553E+00, 1.521E+00, 1.480E+00,...
      1.424E+00, 1.355E+00, 1.272E+00, 1.191E+00, 1.118E+00,...
      1.055E+00, 9.870E-01, 9.136E-01, 8.300E-01, 7.460E-01,...
      6.618E-01, 5.638E-01, 4.614E-01, 3.631E-01, 2.773E-01,...
      2.100E-01, 1.651E-01, 1.500E-01, 1.500E-01, 1.500E-01,...
      1.500E-01, 1.500E-01, 1.500E-01, 1.400E-01, 1.300E-01,...
      1.200E-01, 1.100E-01, 9.500E-02, 6.000E-02, 3.000E-02];
      CH4(2,:) = [...                                   
      1.700E+00, 1.700E+00, 1.700E+00, 1.700E+00, 1.697E+00,...
      1.687E+00, 1.672E+00, 1.649E+00, 1.629E+00, 1.615E+00,...
      1.579E+00, 1.542E+00, 1.508E+00, 1.479E+00, 1.451E+00,...
      1.422E+00, 1.390E+00, 1.356E+00, 1.323E+00, 1.281E+00,...
      1.224E+00, 1.154E+00, 1.066E+00, 9.730E-01, 8.800E-01,...
      7.888E-01, 7.046E-01, 6.315E-01, 5.592E-01, 5.008E-01,...
      4.453E-01, 3.916E-01, 3.389E-01, 2.873E-01, 2.384E-01,...
      1.944E-01, 1.574E-01, 1.500E-01, 1.500E-01, 1.500E-01,...
      1.500E-01, 1.500E-01, 1.500E-01, 1.400E-01, 1.300E-01,...
      1.200E-01, 1.100E-01, 9.500E-02, 6.000E-02, 3.000E-02];
      CH4(3,:) = [...                                   
      1.700E+00, 1.700E+00, 1.700E+00, 1.700E+00, 1.697E+00,...
      1.687E+00, 1.672E+00, 1.649E+00, 1.629E+00, 1.615E+00,...
      1.579E+00, 1.542E+00, 1.508E+00, 1.479E+00, 1.451E+00,...
      1.422E+00, 1.390E+00, 1.356E+00, 1.323E+00, 1.281E+00,...
      1.224E+00, 1.154E+00, 1.066E+00, 9.730E-01, 8.800E-01,...
      7.931E-01, 7.130E-01, 6.438E-01, 5.746E-01, 5.050E-01,...
      4.481E-01, 3.931E-01, 3.395E-01, 2.876E-01, 2.386E-01,...
      1.944E-01, 1.574E-01, 1.500E-01, 1.500E-01, 1.500E-01,...
      1.500E-01, 1.500E-01, 1.500E-01, 1.400E-01, 1.300E-01,...
      1.200E-01, 1.100E-01, 9.500E-02, 6.000E-02, 3.000E-02];
      CH4(4,:) = [...                                   
      1.700E+00, 1.700E+00, 1.700E+00, 1.700E+00, 1.697E+00,...
      1.687E+00, 1.672E+00, 1.649E+00, 1.629E+00, 1.615E+00,...
      1.579E+00, 1.542E+00, 1.506E+00, 1.471E+00, 1.434E+00,...
      1.389E+00, 1.342E+00, 1.290E+00, 1.230E+00, 1.157E+00,...
      1.072E+00, 9.903E-01, 9.170E-01, 8.574E-01, 8.013E-01,...
      7.477E-01, 6.956E-01, 6.442E-01, 5.888E-01, 5.240E-01,...
      4.506E-01, 3.708E-01, 2.992E-01, 2.445E-01, 2.000E-01,...
      1.660E-01, 1.500E-01, 1.500E-01, 1.500E-01, 1.500E-01,...
      1.500E-01, 1.500E-01, 1.500E-01, 1.400E-01, 1.300E-01,...
      1.200E-01, 1.100E-01, 9.500E-02, 6.000E-02, 3.000E-02];
      CH4(5,:) = [...                                   
      1.700E+00, 1.700E+00, 1.700E+00, 1.700E+00, 1.697E+00,...
      1.687E+00, 1.672E+00, 1.649E+00, 1.629E+00, 1.615E+00,...
      1.579E+00, 1.542E+00, 1.506E+00, 1.471E+00, 1.434E+00,...
      1.389E+00, 1.342E+00, 1.290E+00, 1.230E+00, 1.161E+00,...
      1.084E+00, 1.014E+00, 9.561E-01, 9.009E-01, 8.479E-01,...
      7.961E-01, 7.449E-01, 6.941E-01, 6.434E-01, 5.883E-01,...
      5.238E-01, 4.505E-01, 3.708E-01, 3.004E-01, 2.453E-01,...
      1.980E-01, 1.590E-01, 1.500E-01, 1.500E-01, 1.500E-01,...
      1.500E-01, 1.500E-01, 1.500E-01, 1.400E-01, 1.300E-01,...
      1.200E-01, 1.100E-01, 9.500E-02, 6.000E-02, 3.000E-02];
      CH4(6,:) = [...                                   
      1.700E+00, 1.700E+00, 1.700E+00, 1.700E+00, 1.700E+00,...
      1.700E+00, 1.700E+00, 1.699E+00, 1.697E+00, 1.693E+00,...
      1.685E+00, 1.675E+00, 1.662E+00, 1.645E+00, 1.626E+00,...
      1.605E+00, 1.582E+00, 1.553E+00, 1.521E+00, 1.480E+00,...
      1.424E+00, 1.355E+00, 1.272E+00, 1.191E+00, 1.118E+00,...
      1.055E+00, 9.870E-01, 9.136E-01, 8.300E-01, 7.460E-01,...
      6.618E-01, 5.638E-01, 4.614E-01, 3.631E-01, 2.773E-01,...
      2.100E-01, 1.650E-01, 1.500E-01, 1.500E-01, 1.500E-01,...
      1.500E-01, 1.500E-01, 1.500E-01, 1.400E-01, 1.300E-01,...
      1.200E-01, 1.100E-01, 9.500E-02, 6.000E-02, 3.000E-02];
h5create(fileh5,'/CH4',[6,size(CH4,2)])
h5write(fileh5,'/CH4',CH4)
h5writeatt(fileh5,'/CH4','unit','ppmv');

%     DATA O2        ];
      O2(1,:) = [...                                   
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.000E+05, 1.900E+05, 1.800E+05,...
      1.600E+05, 1.400E+05, 1.200E+05, 9.400E+04, 7.250E+04];
      O2(2,:) = [...                                   
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.000E+05, 1.900E+05, 1.800E+05,...
      1.600E+05, 1.400E+05, 1.200E+05, 9.400E+04, 7.250E+04];
      O2(3,:) = [...                                   
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.000E+05, 1.900E+05, 1.800E+05,...
      1.600E+05, 1.400E+05, 1.200E+05, 9.400E+04, 7.250E+04];
      O2(4,:) = [...                                   
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.000E+05, 1.900E+05, 1.800E+05,...
      1.600E+05, 1.400E+05, 1.200E+05, 9.400E+04, 7.250E+04];
      O2(5,:) = [...                                   
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.000E+05, 1.900E+05, 1.800E+05,...
      1.600E+05, 1.400E+05, 1.200E+05, 9.400E+04, 7.250E+04];
      O2(6,:) = [...                                   
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05, 2.090E+05,...
      2.090E+05, 2.090E+05, 2.000E+05, 1.900E+05, 1.800E+05,...
      1.600E+05, 1.400E+05, 1.200E+05, 9.400E+04, 7.250E+04];
h5create(fileh5,'/O2',[6,size(O2,2)])
h5write(fileh5,'/O2',O2)
h5writeatt(fileh5,'/O2','unit','ppmv');

%     NO.
      NO = [...                                   
       3.00E-04,  3.00E-04,  3.00E-04,  3.00E-04,  3.00E-04,...
       3.00E-04,  3.00E-04,  3.00E-04,  3.00E-04,  3.00E-04,...
       3.00E-04,  3.00E-04,  3.00E-04,  2.99E-04,  2.95E-04,...
       2.83E-04,  2.68E-04,  2.52E-04,  2.40E-04,  2.44E-04,...
       2.55E-04,  2.77E-04,  3.07E-04,  3.60E-04,  4.51E-04,...
       6.85E-04,  1.28E-03,  2.45E-03,  4.53E-03,  7.14E-03,...
       9.34E-03,  1.12E-02,  1.19E-02,  1.17E-02,  1.10E-02,...
       1.03E-02,  1.01E-02,  1.01E-02,  1.03E-02,  1.15E-02,...
       1.61E-02,  2.68E-02,  7.01E-02,  2.13E-01,  7.12E-01,...
       2.08E+00,  4.50E+00,  7.98E+00,  1.00E+01,  1.00E+01];
h5create(fileh5,'/NO',[1,numel(NO)])
h5write(fileh5,'/NO',NO)
h5writeatt(fileh5,'/NO','unit','ppmv');

%     SO2.
      SO2 = [...                                   
       3.00E-04,  2.74E-04,  2.36E-04,  1.90E-04,  1.46E-04,...
       1.18E-04,  9.71E-05,  8.30E-05,  7.21E-05,  6.56E-05,...
       6.08E-05,  5.79E-05,  5.60E-05,  5.59E-05,  5.64E-05,...
       5.75E-05,  5.75E-05,  5.37E-05,  4.78E-05,  3.97E-05,...
       3.19E-05,  2.67E-05,  2.28E-05,  2.07E-05,  1.90E-05,...
       1.75E-05,  1.54E-05,  1.34E-05,  1.21E-05,  1.16E-05,...
       1.21E-05,  1.36E-05,  1.65E-05,  2.10E-05,  2.77E-05,...
       3.56E-05,  4.59E-05,  5.15E-05,  5.11E-05,  4.32E-05,...
       2.83E-05,  1.33E-05,  5.56E-06,  2.24E-06,  8.96E-07,...
       3.58E-07,  1.43E-07,  5.73E-08,  2.29E-08,  9.17E-09];
h5create(fileh5,'/SO2',[1,numel(SO2)])
h5write(fileh5,'/SO2',SO2)
h5writeatt(fileh5,'/SO2','unit','ppmv');

%     NO2.
      NO2 = [...                                   
       2.30E-05,  2.30E-05,  2.30E-05,  2.30E-05,  2.30E-05,...
       2.30E-05,  2.30E-05,  2.30E-05,  2.30E-05,  2.32E-05,...
       2.38E-05,  2.62E-05,  3.15E-05,  4.45E-05,  7.48E-05,...
       1.71E-04,  3.19E-04,  5.19E-04,  7.71E-04,  1.06E-03,...
       1.39E-03,  1.76E-03,  2.16E-03,  2.58E-03,  3.06E-03,...
       3.74E-03,  4.81E-03,  6.16E-03,  7.21E-03,  7.28E-03,...
       6.26E-03,  4.03E-03,  2.17E-03,  1.15E-03,  6.66E-04,...
       4.43E-04,  3.39E-04,  2.85E-04,  2.53E-04,  2.31E-04,...
       2.15E-04,  2.02E-04,  1.92E-04,  1.83E-04,  1.76E-04,...
       1.70E-04,  1.64E-04,  1.59E-04,  1.55E-04,  1.51E-04];
h5create(fileh5,'/NO2',[1,numel(NO)])
h5write(fileh5,'/NO2',NO2)
h5writeatt(fileh5,'/NO2','unit','ppmv');

%     NH3.
      NH3 = [...                                   
       5.00E-04,  5.00E-04,  4.63E-04,  3.80E-04,  2.88E-04,...
       2.04E-04,  1.46E-04,  9.88E-05,  6.48E-05,  3.77E-05,...
       2.03E-05,  1.09E-05,  6.30E-06,  3.12E-06,  1.11E-06,...
       4.47E-07,  2.11E-07,  1.10E-07,  6.70E-08,  3.97E-08,...
       2.41E-08,  1.92E-08,  1.72E-08,  1.59E-08,  1.44E-08,...
       1.23E-08,  9.37E-09,  6.35E-09,  3.68E-09,  1.82E-09,...
       9.26E-10,  2.94E-10,  8.72E-11,  2.98E-11,  1.30E-11,...
       7.13E-12,  4.80E-12,  3.66E-12,  3.00E-12,  2.57E-12,...
       2.27E-12,  2.04E-12,  1.85E-12,  1.71E-12,  1.59E-12,...
       1.48E-12,  1.40E-12,  1.32E-12,  1.25E-12,  1.19E-12];
h5create(fileh5,'/NH3',[1,numel(NH3)])
h5write(fileh5,'/NH3',NH3)
h5writeatt(fileh5,'/NH3','unit','ppmv');

%     HNO3.
      HNO3 = [...                                   
       5.00E-05,  5.96E-05,  6.93E-05,  7.91E-05,  8.87E-05,...
       9.75E-05,  1.11E-04,  1.26E-04,  1.39E-04,  1.53E-04,...
       1.74E-04,  2.02E-04,  2.41E-04,  2.76E-04,  3.33E-04,...
       4.52E-04,  7.37E-04,  1.31E-03,  2.11E-03,  3.17E-03,...
       4.20E-03,  4.94E-03,  5.46E-03,  5.74E-03,  5.84E-03,...
       5.61E-03,  4.82E-03,  3.74E-03,  2.59E-03,  1.64E-03,...
       9.68E-04,  5.33E-04,  2.52E-04,  1.21E-04,  7.70E-05,...
       5.55E-05,  4.45E-05,  3.84E-05,  3.49E-05,  3.27E-05,...
       3.12E-05,  3.01E-05,  2.92E-05,  2.84E-05,  2.78E-05,...
       2.73E-05,  2.68E-05,  2.64E-05,  2.60E-05,  2.57E-05];
h5create(fileh5,'/HNO3',[1,numel(HNO3)])
h5write(fileh5,'/HNO3',NH3)
h5writeatt(fileh5,'/HNO3','unit','ppmv');

%     OH.
      OH = [...                                   
       4.40E-08,  4.40E-08,  4.40E-08,  4.40E-08,  4.40E-08,...
       4.40E-08,  4.40E-08,  4.41E-08,  4.45E-08,  4.56E-08,...
       4.68E-08,  4.80E-08,  4.94E-08,  5.19E-08,  5.65E-08,...
       6.75E-08,  8.25E-08,  1.04E-07,  1.30E-07,  1.64E-07,...
       2.16E-07,  3.40E-07,  5.09E-07,  7.59E-07,  1.16E-06,...
       2.18E-06,  5.00E-06,  1.17E-05,  3.40E-05,  8.35E-05,...
       1.70E-04,  2.85E-04,  4.06E-04,  5.11E-04,  5.79E-04,...
       6.75E-04,  9.53E-04,  1.76E-03,  3.74E-03,  7.19E-03,...
       1.12E-02,  1.13E-02,  6.10E-03,  1.51E-03,  2.42E-04,...
       4.47E-05,  1.77E-05,  1.19E-05,  1.35E-05,  2.20E-05];

%     HF.
      HF = [...                                   
       1.00E-08,  1.00E-08,  1.23E-08,  1.97E-08,  3.18E-08,...
       5.63E-08,  9.18E-08,  1.53E-07,  2.41E-07,  4.04E-07,...
       6.57E-07,  1.20E-06,  1.96E-06,  3.12E-06,  4.62E-06,...
       7.09E-06,  1.05E-05,  1.69E-05,  2.57E-05,  4.02E-05,...
       5.77E-05,  7.77E-05,  9.90E-05,  1.23E-04,  1.50E-04,...
       1.82E-04,  2.30E-04,  2.83E-04,  3.20E-04,  3.48E-04,...
       3.72E-04,  3.95E-04,  4.10E-04,  4.21E-04,  4.24E-04,...
       4.25E-04,  4.25E-04,  4.25E-04,  4.25E-04,  4.25E-04,...
       4.25E-04,  4.25E-04,  4.25E-04,  4.25E-04,  4.25E-04,...
       4.25E-04,  4.25E-04,  4.25E-04,  4.25E-04,  4.25E-04];

%     HCL.
      HCL = [...                                   
       1.00E-03,  7.49E-04,  5.61E-04,  4.22E-04,  3.19E-04,...
       2.39E-04,  1.79E-04,  1.32E-04,  9.96E-05,  7.48E-05,...
       5.68E-05,  4.59E-05,  4.36E-05,  6.51E-05,  1.01E-04,...
       1.63E-04,  2.37E-04,  3.13E-04,  3.85E-04,  4.42E-04,...
       4.89E-04,  5.22E-04,  5.49E-04,  5.75E-04,  6.04E-04,...
       6.51E-04,  7.51E-04,  9.88E-04,  1.28E-03,  1.57E-03,...
       1.69E-03,  1.74E-03,  1.76E-03,  1.79E-03,  1.80E-03,...
       1.80E-03,  1.80E-03,  1.80E-03,  1.80E-03,  1.80E-03,...
       1.80E-03,  1.80E-03,  1.80E-03,  1.80E-03,  1.80E-03,...
       1.80E-03,  1.80E-03,  1.80E-03,  1.80E-03,  1.80E-03];

%     HBR.
      HBR = [...                                   
       1.70E-06,  1.70E-06,  1.70E-06,  1.70E-06,  1.70E-06,...
       1.70E-06,  1.70E-06,  1.70E-06,  1.70E-06,  1.70E-06,...
       1.70E-06,  1.70E-06,  1.70E-06,  1.70E-06,  1.70E-06,...
       1.70E-06,  1.70E-06,  1.70E-06,  1.70E-06,  1.70E-06,...
       1.70E-06,  1.70E-06,  1.70E-06,  1.70E-06,  1.70E-06,...
       1.71E-06,  1.76E-06,  1.90E-06,  2.26E-06,  2.82E-06,...
       3.69E-06,  4.91E-06,  6.13E-06,  6.85E-06,  7.08E-06,...
       7.14E-06,  7.15E-06,  7.15E-06,  7.15E-06,  7.15E-06,...
       7.15E-06,  7.15E-06,  7.15E-06,  7.15E-06,  7.15E-06,...
       7.15E-06,  7.15E-06,  7.15E-06,  7.15E-06,  7.15E-06];

%     HI.
      HI = [...                                   
       3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,...
       3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,...
       3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,...
       3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,...
       3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,...
       3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,...
       3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,...
       3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,...
       3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,...
       3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06,  3.00E-06];

%     CLO.
      CLO = [...                                   
       1.00E-08,  1.00E-08,  1.00E-08,  1.00E-08,  1.00E-08,...
       1.00E-08,  1.00E-08,  1.00E-08,  1.01E-08,  1.05E-08,...
       1.21E-08,  1.87E-08,  3.18E-08,  5.61E-08,  9.99E-08,...
       1.78E-07,  3.16E-07,  5.65E-07,  1.04E-06,  2.04E-06,...
       4.64E-06,  8.15E-06,  1.07E-05,  1.52E-05,  2.24E-05,...
       3.97E-05,  8.48E-05,  1.85E-04,  3.57E-04,  5.08E-04,...
       6.07E-04,  5.95E-04,  4.33E-04,  2.51E-04,  1.56E-04,...
       1.04E-04,  7.69E-05,  6.30E-05,  5.52E-05,  5.04E-05,...
       4.72E-05,  4.49E-05,  4.30E-05,  4.16E-05,  4.03E-05,...
       3.93E-05,  3.83E-05,  3.75E-05,  3.68E-05,  3.61E-05];

%     OCS.
      OCS = [...                                   
       6.00E-04,  5.90E-04,  5.80E-04,  5.70E-04,  5.62E-04,...
       5.55E-04,  5.48E-04,  5.40E-04,  5.32E-04,  5.25E-04,...
       5.18E-04,  5.09E-04,  4.98E-04,  4.82E-04,  4.60E-04,...
       4.26E-04,  3.88E-04,  3.48E-04,  3.09E-04,  2.74E-04,...
       2.41E-04,  2.14E-04,  1.88E-04,  1.64E-04,  1.37E-04,...
       1.08E-04,  6.70E-05,  2.96E-05,  1.21E-05,  4.31E-06,...
       1.60E-06,  6.71E-07,  4.35E-07,  3.34E-07,  2.80E-07,...
       2.47E-07,  2.28E-07,  2.16E-07,  2.08E-07,  2.03E-07,...
       1.98E-07,  1.95E-07,  1.92E-07,  1.89E-07,  1.87E-07,...
       1.85E-07,  1.83E-07,  1.81E-07,  1.80E-07,  1.78E-07];

%     H2CO.
      H2CO = [...                                   
       2.40E-03,  1.07E-03,  4.04E-04,  2.27E-04,  1.40E-04,...
       1.00E-04,  7.44E-05,  6.04E-05,  5.01E-05,  4.22E-05,...
       3.63E-05,  3.43E-05,  3.39E-05,  3.50E-05,  3.62E-05,...
       3.62E-05,  3.58E-05,  3.50E-05,  3.42E-05,  3.39E-05,...
       3.43E-05,  3.68E-05,  4.03E-05,  4.50E-05,  5.06E-05,...
       5.82E-05,  7.21E-05,  8.73E-05,  1.01E-04,  1.11E-04,...
       1.13E-04,  1.03E-04,  7.95E-05,  4.82E-05,  1.63E-05,...
       5.10E-06,  2.00E-06,  1.05E-06,  6.86E-07,  5.14E-07,...
       4.16E-07,  3.53E-07,  3.09E-07,  2.76E-07,  2.50E-07,...
       2.30E-07,  2.13E-07,  1.98E-07,  1.86E-07,  1.75E-07];

%     HOCL.
      HOCL = [...                                   
       7.70E-06,  1.06E-05,  1.22E-05,  1.14E-05,  9.80E-06,...
       8.01E-06,  6.42E-06,  5.42E-06,  4.70E-06,  4.41E-06,...
       4.34E-06,  4.65E-06,  5.01E-06,  5.22E-06,  5.60E-06,...
       6.86E-06,  8.77E-06,  1.20E-05,  1.63E-05,  2.26E-05,...
       3.07E-05,  4.29E-05,  5.76E-05,  7.65E-05,  9.92E-05,...
       1.31E-04,  1.84E-04,  2.45E-04,  2.96E-04,  3.21E-04,...
       3.04E-04,  2.48E-04,  1.64E-04,  9.74E-05,  4.92E-05,...
       2.53E-05,  1.50E-05,  1.05E-05,  8.34E-06,  7.11E-06,...
       6.33E-06,  5.78E-06,  5.37E-06,  5.05E-06,  4.78E-06,...
       4.56E-06,  4.37E-06,  4.21E-06,  4.06E-06,  3.93E-06];

%     N2.
      N2 = [...                                   
       7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,...
       7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,...
       7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,...
       7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,...
       7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,...
       7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,...
       7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,...
       7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,  7.81E+05,...
       7.81E+05,  7.81E+05,  7.81E+05,  7.80E+05,  7.79E+05,...
       7.77E+05,  7.74E+05,  7.70E+05,  7.65E+05,  7.60E+05];

%     HCN.
      HCN = [...                                   
       1.70E-04,  1.65E-04,  1.63E-04,  1.61E-04,  1.60E-04,...
       1.60E-04,  1.60E-04,  1.60E-04,  1.60E-04,  1.60E-04,...
       1.60E-04,  1.60E-04,  1.60E-04,  1.59E-04,  1.57E-04,...
       1.55E-04,  1.52E-04,  1.49E-04,  1.45E-04,  1.41E-04,...
       1.37E-04,  1.34E-04,  1.30E-04,  1.25E-04,  1.19E-04,...
       1.13E-04,  1.05E-04,  9.73E-05,  9.04E-05,  8.46E-05,...
       8.02E-05,  7.63E-05,  7.30E-05,  7.00E-05,  6.70E-05,...
       6.43E-05,  6.21E-05,  6.02E-05,  5.88E-05,  5.75E-05,...
       5.62E-05,  5.50E-05,  5.37E-05,  5.25E-05,  5.12E-05,...
       5.00E-05,  4.87E-05,  4.75E-05,  4.62E-05,  4.50E-05];

%     CH3CL.
      CH3CL = [...                                   
       7.00E-04,  6.70E-04,  6.43E-04,  6.22E-04,  6.07E-04,...
       6.02E-04,  6.00E-04,  6.00E-04,  5.98E-04,  5.94E-04,...
       5.88E-04,  5.79E-04,  5.66E-04,  5.48E-04,  5.28E-04,...
       5.03E-04,  4.77E-04,  4.49E-04,  4.21E-04,  3.95E-04,...
       3.69E-04,  3.43E-04,  3.17E-04,  2.86E-04,  2.48E-04,...
       1.91E-04,  1.10E-04,  4.72E-05,  1.79E-05,  7.35E-06,...
       3.03E-06,  1.32E-06,  8.69E-07,  6.68E-07,  5.60E-07,...
       4.94E-07,  4.56E-07,  4.32E-07,  4.17E-07,  4.05E-07,...
       3.96E-07,  3.89E-07,  3.83E-07,  3.78E-07,  3.73E-07,...
       3.69E-07,  3.66E-07,  3.62E-07,  3.59E-07,  3.56E-07];

%     H2O2.
      H2O2 = [...                                   
       2.00E-04,  1.95E-04,  1.92E-04,  1.89E-04,  1.84E-04,...
       1.77E-04,  1.66E-04,  1.49E-04,  1.23E-04,  9.09E-05,...
       5.79E-05,  3.43E-05,  1.95E-05,  1.08E-05,  6.59E-06,...
       4.20E-06,  2.94E-06,  2.30E-06,  2.24E-06,  2.68E-06,...
       3.68E-06,  5.62E-06,  1.03E-05,  1.97E-05,  3.70E-05,...
       6.20E-05,  1.03E-04,  1.36E-04,  1.36E-04,  1.13E-04,...
       8.51E-05,  6.37E-05,  5.17E-05,  4.44E-05,  3.80E-05,...
       3.48E-05,  3.62E-05,  5.25E-05,  1.26E-04,  3.77E-04,...
       1.12E-03,  2.00E-03,  1.68E-03,  4.31E-04,  4.98E-05,...
       6.76E-06,  8.38E-07,  9.56E-08,  1.00E-08,  1.00E-09];

%     C2H2.
      C2H2 = [...                                   
       3.00E-04,  1.72E-04,  9.57E-05,  6.74E-05,  5.07E-05,...
       3.99E-05,  3.19E-05,  2.80E-05,  2.55E-05,  2.40E-05,...
       2.27E-05,  2.08E-05,  1.76E-05,  1.23E-05,  7.32E-06,...
       4.52E-06,  2.59E-06,  1.55E-06,  8.63E-07,  5.30E-07,...
       3.10E-07,  1.89E-07,  1.04E-07,  5.75E-08,  2.23E-08,...
       8.51E-09,  4.09E-09,  2.52E-09,  1.86E-09,  1.52E-09,...
       1.32E-09,  1.18E-09,  1.08E-09,  9.97E-10,  9.34E-10,...
       8.83E-10,  8.43E-10,  8.10E-10,  7.83E-10,  7.60E-10,...
       7.40E-10,  7.23E-10,  7.07E-10,  6.94E-10,  6.81E-10,...
       6.70E-10,  6.59E-10,  6.49E-10,  6.40E-10,  6.32E-10];

%     C2H6.
      C2H6 = [...                                   
       2.00E-03,  2.00E-03,  2.00E-03,  2.00E-03,  1.98E-03,...
       1.95E-03,  1.90E-03,  1.85E-03,  1.79E-03,  1.72E-03,...
       1.58E-03,  1.30E-03,  9.86E-04,  7.22E-04,  4.96E-04,...
       3.35E-04,  2.14E-04,  1.49E-04,  1.05E-04,  7.96E-05,...
       6.01E-05,  4.57E-05,  3.40E-05,  2.60E-05,  1.89E-05,...
       1.22E-05,  5.74E-06,  2.14E-06,  8.49E-07,  3.42E-07,...
       1.34E-07,  5.39E-08,  2.25E-08,  1.04E-08,  6.57E-09,...
       4.74E-09,  3.79E-09,  3.28E-09,  2.98E-09,  2.79E-09,...
       2.66E-09,  2.56E-09,  2.49E-09,  2.43E-09,  2.37E-09,...
       2.33E-09,  2.29E-09,  2.25E-09,  2.22E-09,  2.19E-09];

%     PH3.
      PH3 = [...                                   
       1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,...
       1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,...
       1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,...
       1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,...
       1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,...
       1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,...
       1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,...
       1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,...
       1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,...
       1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14,  1.00E-14];

   